/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_nsV4uerq);
  numBytes += sLine_init(&sLine_dPLnR4QL);
  numBytes += sLine_init(&sLine_YKQB8PKl);
  numBytes += sLine_init(&sLine_jXHFwSib);
  numBytes += sLine_init(&sLine_gVayQMOm);
  numBytes += sBiquad_init(&sBiquad_s_0P8UIzwz);
  numBytes += sLine_init(&sLine_VOKkhjXp);
  numBytes += sLine_init(&sLine_lgVH9r9P);
  numBytes += sLine_init(&sLine_TgyCRvRG);
  numBytes += sLine_init(&sLine_S5iDjuYX);
  numBytes += sBiquad_init(&sBiquad_s_NOuDRmMH);
  numBytes += sLine_init(&sLine_AlIOUUeS);
  numBytes += sLine_init(&sLine_nHfrXWhg);
  numBytes += sLine_init(&sLine_ep8OsNgw);
  numBytes += sLine_init(&sLine_OA2PzEqD);
  numBytes += sLine_init(&sLine_nnoMMfhe);
  numBytes += sBiquad_init(&sBiquad_s_VQ7aJQpz);
  numBytes += sLine_init(&sLine_opGiacve);
  numBytes += sLine_init(&sLine_5hAg9a0S);
  numBytes += sLine_init(&sLine_ooVqBI9U);
  numBytes += sLine_init(&sLine_2AM9LelM);
  numBytes += sLine_init(&sLine_rM9KBoYO);
  numBytes += sBiquad_init(&sBiquad_s_hekgEUPy);
  numBytes += sLine_init(&sLine_yWj0Hgbk);
  numBytes += sLine_init(&sLine_lE8eUZX3);
  numBytes += sLine_init(&sLine_tswci10b);
  numBytes += sLine_init(&sLine_hfciy1kH);
  numBytes += sBiquad_init(&sBiquad_s_MUFCtdsC);
  numBytes += sLine_init(&sLine_F2HZ0jbP);
  numBytes += sLine_init(&sLine_tGyecyQ6);
  numBytes += sLine_init(&sLine_Bryel1eD);
  numBytes += sLine_init(&sLine_rqxQoYkY);
  numBytes += sLine_init(&sLine_8kkCvHsm);
  numBytes += sBiquad_init(&sBiquad_s_M8qI879e);
  numBytes += sLine_init(&sLine_LOR5GWii);
  numBytes += sTabread_init(&sTabread_9cFKXxWJ, &hTable_C1M01EKC, true);
  numBytes += sLine_init(&sLine_1JYytvCh);
  numBytes += sLine_init(&sLine_CeKf1w9K);
  numBytes += sTabread_init(&sTabread_vWg9xjYC, &hTable_3diouaCx, true);
  numBytes += sLine_init(&sLine_zD2bQONr);
  numBytes += sRPole_init(&sRPole_WbtABGCR);
  numBytes += sDel1_init(&sDel1_TzWsLRnE);
  numBytes += sTabwrite_init(&sTabwrite_yVYXdgmK, &hTable_C1M01EKC);
  numBytes += sRPole_init(&sRPole_D1XwAmGm);
  numBytes += sDel1_init(&sDel1_ERiELeAC);
  numBytes += sTabwrite_init(&sTabwrite_SmPzUxpL, &hTable_3diouaCx);
  numBytes += sLine_init(&sLine_Hd762wSD);
  numBytes += sLine_init(&sLine_ZDtrzvZ7);
  numBytes += sRPole_init(&sRPole_pTIEM7rb);
  numBytes += sEnv_init(&sEnv_tfLSvRCy, 1024, 512);
  numBytes += sRPole_init(&sRPole_dIcZ79W1);
  numBytes += sLine_init(&sLine_yzEumBOQ);
  numBytes += sLine_init(&sLine_skU88LJ9);
  numBytes += sRPole_init(&sRPole_VC5iGLgC);
  numBytes += sEnv_init(&sEnv_55KP6IoN, 1024, 512);
  numBytes += sRPole_init(&sRPole_DM6Tjmvu);
  numBytes += sLine_init(&sLine_YhgjhRjv);
  numBytes += sTabread_init(&sTabread_hxDx1eyJ, &hTable_4QLAEMig, true);
  numBytes += sLine_init(&sLine_XWI1IyDr);
  numBytes += sLine_init(&sLine_Jza4JCsW);
  numBytes += sTabread_init(&sTabread_Y3KqbIuB, &hTable_F6LvdaDd, true);
  numBytes += sLine_init(&sLine_0angkyHi);
  numBytes += sRPole_init(&sRPole_EFPxPgKV);
  numBytes += sDel1_init(&sDel1_W4yP4xoV);
  numBytes += sTabwrite_init(&sTabwrite_ktViRj5c, &hTable_4QLAEMig);
  numBytes += sRPole_init(&sRPole_kHH2wQmr);
  numBytes += sDel1_init(&sDel1_KyCNnAur);
  numBytes += sTabwrite_init(&sTabwrite_Xy6G5mBv, &hTable_F6LvdaDd);
  numBytes += sLine_init(&sLine_pjIOgGQ4);
  numBytes += sLine_init(&sLine_c2Rc1CcA);
  numBytes += sRPole_init(&sRPole_UgDflWbC);
  numBytes += sEnv_init(&sEnv_pC0haLX8, 1024, 512);
  numBytes += sRPole_init(&sRPole_mUW6aisG);
  numBytes += sLine_init(&sLine_mBX0svRQ);
  numBytes += sLine_init(&sLine_OHWFhFQT);
  numBytes += sRPole_init(&sRPole_4dptRfFn);
  numBytes += sEnv_init(&sEnv_taa6etC3, 1024, 512);
  numBytes += sRPole_init(&sRPole_8MkHgJw4);
  numBytes += sLine_init(&sLine_2ZOK8yuK);
  numBytes += sTabread_init(&sTabread_LAseoey1, &hTable_DNYritdT, true);
  numBytes += sLine_init(&sLine_EJzAyTEF);
  numBytes += sLine_init(&sLine_2Ng7cm7u);
  numBytes += sTabread_init(&sTabread_OS515Sc0, &hTable_tesrntIS, true);
  numBytes += sLine_init(&sLine_WxdpHsu7);
  numBytes += sRPole_init(&sRPole_Fufab77Z);
  numBytes += sDel1_init(&sDel1_1V6cniFf);
  numBytes += sTabwrite_init(&sTabwrite_htJ9eyzG, &hTable_DNYritdT);
  numBytes += sRPole_init(&sRPole_HBvdx3nj);
  numBytes += sDel1_init(&sDel1_pMJx9bfd);
  numBytes += sTabwrite_init(&sTabwrite_sm9OnF6l, &hTable_tesrntIS);
  numBytes += sLine_init(&sLine_XQSgRPcS);
  numBytes += sLine_init(&sLine_MAfdLDcd);
  numBytes += sRPole_init(&sRPole_LQyVr4E0);
  numBytes += sEnv_init(&sEnv_lX4ULbZb, 1024, 512);
  numBytes += sRPole_init(&sRPole_HeKEWwJe);
  numBytes += sLine_init(&sLine_hNB7W7Fp);
  numBytes += sLine_init(&sLine_TcFc9G7O);
  numBytes += sRPole_init(&sRPole_eYu6ew5q);
  numBytes += sEnv_init(&sEnv_odQ1LWw0, 1024, 512);
  numBytes += sRPole_init(&sRPole_Y5Idb3QT);
  numBytes += cVar_init_f(&cVar_RPXKyyOi, 0.0f);
  numBytes += cVar_init_f(&cVar_H8zC2EH3, 0.0f);
  numBytes += cVar_init_f(&cVar_CM8U0isk, 0.0f);
  numBytes += cVar_init_f(&cVar_geZKhTIc, 0.0f);
  numBytes += cSlice_init(&cSlice_zjvZahAG, 1, -1);
  numBytes += cVar_init_f(&cVar_vHambIEX, 1337.0f);
  numBytes += cVar_init_f(&cVar_6AEvqyYL, 0.0f);
  numBytes += cIf_init(&cIf_K8ytCMD9, false);
  numBytes += cIf_init(&cIf_2DVnUfb1, false);
  numBytes += cBinop_init(&cBinop_y9YgHKVI, 0.0f); // __pow
  numBytes += cIf_init(&cIf_L8JS0AkY, false);
  numBytes += cBinop_init(&cBinop_CvdwgLM0, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_XdEGSEkV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_NZBIzGRt, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_PgvrsENs, 0.0f);
  numBytes += cIf_init(&cIf_Zr8SMpWK, false);
  numBytes += cIf_init(&cIf_Et0VErcl, false);
  numBytes += cBinop_init(&cBinop_dOMcAN3x, 0.0f); // __pow
  numBytes += cIf_init(&cIf_7sO1sRQH, false);
  numBytes += cBinop_init(&cBinop_V18f7jta, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_PegZuKib, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_iKkRywTN, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_lbvw8vXO, 0.0f);
  numBytes += cIf_init(&cIf_J4aZzWGV, false);
  numBytes += cIf_init(&cIf_cbvFGwWe, false);
  numBytes += cBinop_init(&cBinop_l1xvwtWy, 0.0f); // __pow
  numBytes += cIf_init(&cIf_1jZq3nP8, false);
  numBytes += cBinop_init(&cBinop_gflhew0J, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_5e0H0pAD, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_cbzrgXKr, -15.0f); // __eq
  numBytes += cIf_init(&cIf_Q2rhlfkJ, false);
  numBytes += cSlice_init(&cSlice_ufkaEtSj, 1, -1);
  numBytes += cVar_init_f(&cVar_pSRIDGyo, 0.0f);
  numBytes += cSlice_init(&cSlice_HBlKadON, 1, -1);
  numBytes += cVar_init_f(&cVar_5UYTfJx8, 0.0f);
  numBytes += cSlice_init(&cSlice_e0njoGMZ, 1, -1);
  numBytes += cVar_init_f(&cVar_McYVz5jP, 0.0f);
  numBytes += cSlice_init(&cSlice_LVBtkiiP, 1, -1);
  numBytes += cVar_init_f(&cVar_V3Jq9Upj, 0.313f);
  numBytes += cBinop_init(&cBinop_ismTlifP, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_0zkP2YeD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_q5N8Ke1W, 0.0f);
  numBytes += cVar_init_f(&cVar_m3US40Fr, 1337.0f);
  numBytes += cVar_init_f(&cVar_GRlp1Rp1, 0.3f);
  numBytes += cBinop_init(&cBinop_T1vFAwOs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OOwiSfvT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bxmws1wG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_caxZLLyE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V9CrKshN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_q5TXqq3a, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Dd4Z6CC4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ehBrUDLG, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_fPi6XtNZ, 0.0f);
  numBytes += cVar_init_f(&cVar_MLEcfNss, 1337.0f);
  numBytes += cVar_init_f(&cVar_7mGWCI2c, 0.313f);
  numBytes += cBinop_init(&cBinop_8TbnSnfq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oIpa1PKw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dhBgxwXb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UYehTwRj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sAaotkrA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vMadsfy4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_W81OqNQn, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_NMB5rSoA, 0.0f);
  numBytes += cVar_init_f(&cVar_WhM2yYxb, 1037.0f);
  numBytes += cVar_init_f(&cVar_nR2Yp82y, 0.4f);
  numBytes += cBinop_init(&cBinop_f8v9vxcH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rFTApYwf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_phOIRdnQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9s2UqUM6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bVMZc43S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_R73fKFRT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6SSw5Axv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5N2N1hgI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_59UxGIX9, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_UAm1nyVl, 1, -1);
  numBytes += cVar_init_f(&cVar_FUjhbxH8, 1337.0f);
  numBytes += cVar_init_f(&cVar_TuJnkEyo, 0.0f);
  numBytes += cIf_init(&cIf_qaGe96DY, false);
  numBytes += cIf_init(&cIf_yOuOWxVC, false);
  numBytes += cBinop_init(&cBinop_wqZ85Fwj, 0.0f); // __pow
  numBytes += cIf_init(&cIf_CAJqTLIO, false);
  numBytes += cBinop_init(&cBinop_g3x8GmJU, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_5A6QFjta, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_W1nzgXun, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_LF48vs4x, 0.0f);
  numBytes += cIf_init(&cIf_B5Ia1xan, false);
  numBytes += cIf_init(&cIf_AOPEnRGt, false);
  numBytes += cBinop_init(&cBinop_WhFQunV8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0Z9p1na2, false);
  numBytes += cBinop_init(&cBinop_FiZCzO70, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_TSMV7ffX, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_CH2rEgaE, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_cfLxEaI8, 0.0f);
  numBytes += cIf_init(&cIf_WfaHsUJM, false);
  numBytes += cIf_init(&cIf_GNXymE4A, false);
  numBytes += cBinop_init(&cBinop_Zi1jO487, 0.0f); // __pow
  numBytes += cIf_init(&cIf_MwZZ2WIf, false);
  numBytes += cBinop_init(&cBinop_PtegXVXZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_lHcu7IOM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_0f7AgvAB, -15.0f); // __eq
  numBytes += cIf_init(&cIf_xY5LfiLw, false);
  numBytes += cSlice_init(&cSlice_eoGyAemu, 1, -1);
  numBytes += cVar_init_f(&cVar_IXiT00rK, 0.0f);
  numBytes += cSlice_init(&cSlice_kDWweVL6, 1, -1);
  numBytes += cVar_init_f(&cVar_Z5xlp1EC, 0.0f);
  numBytes += cSlice_init(&cSlice_PzIdl3Sy, 1, -1);
  numBytes += cVar_init_f(&cVar_Vqcc5Gng, 0.0f);
  numBytes += cSlice_init(&cSlice_XjaZbYdw, 1, -1);
  numBytes += cVar_init_f(&cVar_ZPBUUjFs, 0.313f);
  numBytes += cBinop_init(&cBinop_zBc16X76, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_yOFQCiP4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_E3LHPAaw, 0.0f);
  numBytes += cVar_init_f(&cVar_TImns3GS, 1337.0f);
  numBytes += cVar_init_f(&cVar_SJK5Gi6m, 0.3f);
  numBytes += cBinop_init(&cBinop_XGzsLLH4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KXNZFYGl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SOPGL2tL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_H4ySKhYd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NjCpe9yS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PX94EJky, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gXpbApS0, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_DjvBmiRz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_aUkPnTaV, 0.0f);
  numBytes += cVar_init_f(&cVar_8Om0u302, 1337.0f);
  numBytes += cVar_init_f(&cVar_QJtdPZTE, 0.313f);
  numBytes += cBinop_init(&cBinop_ROIPKFVU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MIMxq6L2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZeTrXHf8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_d9zWfMz5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rMnJxSRs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9SU9joBI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Eoa9VwSW, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_OB9sv3XN, 0.0f);
  numBytes += cVar_init_f(&cVar_Gl0axYie, 1037.0f);
  numBytes += cVar_init_f(&cVar_8Dh5LaeR, 0.4f);
  numBytes += cBinop_init(&cBinop_1lKt6NJw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EpC44Vpq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dWvKJ93J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4Y1Be6q4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_u9pkXiZa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_47nKLezE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_M6xarT90, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WKow0uYQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_n9u48uKW, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_G4hIVrZ9, 5705.6f);
  numBytes += cVar_init_f(&cVar_Za51Z6Cv, 313.3f);
  numBytes += cBinop_init(&cBinop_KCQqkwAG, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_k0adVJbG, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_xmxz6Cpk, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_Pz7IiZ4h, 0.0f);
  numBytes += cVar_init_f(&cVar_wLbom7n5, 0.0f);
  numBytes += cVar_init_f(&cVar_AzHckjiT, 0.0f);
  numBytes += cVar_init_f(&cVar_upl7LidO, 0.0f);
  numBytes += cVar_init_f(&cVar_NDCK0Ko3, 0.0f);
  numBytes += cVar_init_f(&cVar_UXUyAgt9, 0.0f);
  numBytes += cVar_init_f(&cVar_zqSvPUYX, 0.0f);
  numBytes += cVar_init_f(&cVar_zLHlqDdI, 0.0f);
  numBytes += cVar_init_f(&cVar_XJzPYWdO, 0.0f);
  numBytes += cVar_init_f(&cVar_bX1eWhFI, 0.0f);
  numBytes += cVar_init_f(&cVar_khUz6vQ2, 0.0f);
  numBytes += cVar_init_f(&cVar_27Lh8F9I, 0.0f);
  numBytes += cSlice_init(&cSlice_I47MFrti, 1, -1);
  numBytes += cVar_init_f(&cVar_5r2GFnDP, 0.5f);
  numBytes += cSlice_init(&cSlice_G7y1EsKP, 1, -1);
  numBytes += cVar_init_f(&cVar_eeCNNVbK, 0.2f);
  numBytes += cSlice_init(&cSlice_3ZLWpZYC, 1, -1);
  numBytes += cVar_init_f(&cVar_QSwPtEPQ, 500.0f);
  numBytes += sVarf_init(&sVarf_sx31WiGk, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TO0s0kQc, 600.0f);
  numBytes += cBinop_init(&cBinop_nj2pq9el, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_jtkLSGqn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_N9BPWZfv, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_AZJWbHH1, 600.0f);
  numBytes += cBinop_init(&cBinop_O8XaKNFv, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_skHSI109, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dCwV0CS8, 4000.0f);
  numBytes += cBinop_init(&cBinop_bbybZmvb, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pek8aLU3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RYWaEv3h, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_q5Nqp00O, 4000.0f);
  numBytes += cBinop_init(&cBinop_9JE7Lolx, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qYVbZbpp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OZQWpaI0, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_YdBth31i, false);
  numBytes += cBinop_init(&cBinop_9f7fRbLN, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_xOAs8MeD, 20.0f);
  numBytes += cBinop_init(&cBinop_q6ThVeat, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_14ZPZnd8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PyRPJVuT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dWlyBku3, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_87uBwI4b, false);
  numBytes += cBinop_init(&cBinop_NC1Ko4xQ, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_Sk8hEjxd, 20.0f);
  numBytes += cBinop_init(&cBinop_ntCJYLk8, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_L3YdiH04, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l2zoK9xY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3zAt7r5c, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_UCXsT1mP, 1, -1);
  numBytes += cVar_init_f(&cVar_hhZ7SzXP, 0.25f);
  numBytes += cDelay_init(this, &cDelay_YiYmx5Eg, 0.0f);
  numBytes += cDelay_init(this, &cDelay_yRYZcgnN, 0.0f);
  numBytes += hTable_init(&hTable_C1M01EKC, 256);
  numBytes += cTabhead_init(&cTabhead_JiTHS9b2, &hTable_C1M01EKC);
  numBytes += cVar_init_s(&cVar_QCRVe9xj, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_Y0E8Q3df, 0.0f);
  numBytes += cDelay_init(this, &cDelay_2t3fQCiS, 0.0f);
  numBytes += cBinop_init(&cBinop_DGqrMahT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rQHztwPx, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_tIULSN37, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_QS9yz47a, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_9j9cvOhp, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Op88u6S7, 0.0f);
  numBytes += hTable_init(&hTable_3diouaCx, 256);
  numBytes += cTabhead_init(&cTabhead_8ijs9hwY, &hTable_3diouaCx);
  numBytes += cVar_init_s(&cVar_XHVzo0WA, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_XW6kGLKy, 0.0f);
  numBytes += cDelay_init(this, &cDelay_zp4G1bk8, 0.0f);
  numBytes += cBinop_init(&cBinop_ezaN5XMn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_r4SvlNtJ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_bCGG9T6B, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_j7x0Bbev, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_XSFm1GSZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T3Z5LTXx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xsGiZMWw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_D5LzNP7Q, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_EQULPBCg, 1, -1);
  numBytes += cVar_init_f(&cVar_3yifbHA8, 0.5f);
  numBytes += cSlice_init(&cSlice_1AkSq7iB, 1, -1);
  numBytes += cVar_init_f(&cVar_e6ar8BTK, 0.2f);
  numBytes += cSlice_init(&cSlice_wHq9SPRr, 1, -1);
  numBytes += cVar_init_f(&cVar_d6r7N2ix, 500.0f);
  numBytes += sVarf_init(&sVarf_dad4jLYG, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vlwpPazn, 600.0f);
  numBytes += cBinop_init(&cBinop_BSsI2AEt, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_EHMnHpFk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nBK5Q9GP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_QVgfR36H, 600.0f);
  numBytes += cBinop_init(&cBinop_8XVcdy7Y, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_EsNytzSR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_XLNCODwD, 4000.0f);
  numBytes += cBinop_init(&cBinop_Rht77Iz5, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6bm6zYOo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8rm93nrG, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_SXbN6DTP, 4000.0f);
  numBytes += cBinop_init(&cBinop_r2JLubuE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tGhZiupz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_noaOPQBm, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_kPwISEjR, false);
  numBytes += cBinop_init(&cBinop_p3IFL9JI, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_frTIvtwG, 20.0f);
  numBytes += cBinop_init(&cBinop_12inedSY, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fkQJci3v, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uEPVgiph, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4Gbu39bu, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_vi3MxSOq, false);
  numBytes += cBinop_init(&cBinop_9bSLrCXR, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_eWUAFDJx, 20.0f);
  numBytes += cBinop_init(&cBinop_dcwRl2Am, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_L7VNmyLZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ObrkNkPi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1M7sNqMW, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_i2UhBaJ7, 1, -1);
  numBytes += cVar_init_f(&cVar_axcj3w7O, 0.25f);
  numBytes += cDelay_init(this, &cDelay_AebW6Lr9, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xdFTMbW9, 0.0f);
  numBytes += hTable_init(&hTable_4QLAEMig, 256);
  numBytes += cTabhead_init(&cTabhead_RcJsIeiH, &hTable_4QLAEMig);
  numBytes += cVar_init_s(&cVar_bvuPeikZ, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_Ho6Fytjm, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ol7jg8Dc, 0.0f);
  numBytes += cBinop_init(&cBinop_nZ2V9UTq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7WZd74cV, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_KImkklxD, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_DDD6DDas, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_fzj2a77r, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ab54VjFI, 0.0f);
  numBytes += hTable_init(&hTable_F6LvdaDd, 256);
  numBytes += cTabhead_init(&cTabhead_9tMTbkXc, &hTable_F6LvdaDd);
  numBytes += cVar_init_s(&cVar_vSzkcySE, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_YcJhrBHT, 0.0f);
  numBytes += cDelay_init(this, &cDelay_McO6x1Hn, 0.0f);
  numBytes += cBinop_init(&cBinop_84ywi2q3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BSeWEdJX, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_uYbzT9gl, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_bPJgWqDk, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_xtiolNpd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rYGPYTpp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kIyTfmGz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MDiFpYpi, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_zlYVsVbr, 1, -1);
  numBytes += cVar_init_f(&cVar_9BAYDLNm, 0.5f);
  numBytes += cSlice_init(&cSlice_jrd693Np, 1, -1);
  numBytes += cVar_init_f(&cVar_nuINDAUj, 0.2f);
  numBytes += cSlice_init(&cSlice_00Suq8Pa, 1, -1);
  numBytes += cVar_init_f(&cVar_lSJH5rFP, 500.0f);
  numBytes += sVarf_init(&sVarf_iSDBH07R, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HExhlo9d, 600.0f);
  numBytes += cBinop_init(&cBinop_ak2HSnIm, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_pCtS5Ub7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4U9gcFBv, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_APBEyypz, 600.0f);
  numBytes += cBinop_init(&cBinop_MwjmydF4, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_aLXQHzo8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_K5UJrBEC, 4000.0f);
  numBytes += cBinop_init(&cBinop_J2hsTXRU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_8ejYyDhg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TXimwrM2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_j3PXL7fR, 4000.0f);
  numBytes += cBinop_init(&cBinop_acGh7s1y, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_o28JgQuI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J8GQdxlw, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_bsBDNogO, false);
  numBytes += cBinop_init(&cBinop_q7hrarpB, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_7JXDPl2B, 20.0f);
  numBytes += cBinop_init(&cBinop_3QarwxNp, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_CUqx9Jid, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f2wrFm8M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K8IwvA26, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_hpS1cbPP, false);
  numBytes += cBinop_init(&cBinop_w1nr1MYZ, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_X2IJW4h1, 20.0f);
  numBytes += cBinop_init(&cBinop_bu2NeutZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_B2IV0J2l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w7RVsEZ3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_12DoSdqy, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_XLi4S974, 1, -1);
  numBytes += cVar_init_f(&cVar_YevAvDzo, 0.25f);
  numBytes += cDelay_init(this, &cDelay_LBr5c4Zk, 0.0f);
  numBytes += cDelay_init(this, &cDelay_aGZQt0Wl, 0.0f);
  numBytes += hTable_init(&hTable_DNYritdT, 256);
  numBytes += cTabhead_init(&cTabhead_ePfJuK21, &hTable_DNYritdT);
  numBytes += cVar_init_s(&cVar_mkL8c0a5, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_kN2oplHW, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kqsW3saM, 0.0f);
  numBytes += cBinop_init(&cBinop_exOdtGyP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cWvh5XSv, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Pb17LNEc, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_DuFy9irL, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_a3KNOIqO, 0.0f);
  numBytes += cDelay_init(this, &cDelay_8bFQBSKS, 0.0f);
  numBytes += hTable_init(&hTable_tesrntIS, 256);
  numBytes += cTabhead_init(&cTabhead_PM1dtp2u, &hTable_tesrntIS);
  numBytes += cVar_init_s(&cVar_3zCfgQ08, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_1upZjZZf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_CSH8RbPa, 0.0f);
  numBytes += cBinop_init(&cBinop_bhd8AzKT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_utROhXnp, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_VaMACcgP, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_olufSs3J, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_PJLHjhVd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NgjzAzQR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VcbUlWtG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IF57ip2X, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MUjeg1GT, 1.0f);
  numBytes += cIf_init(&cIf_De80G73G, false);
  numBytes += cIf_init(&cIf_JMr8mfdZ, false);
  numBytes += cVar_init_f(&cVar_ZqsTwUCm, 0.0f);
  numBytes += cVar_init_f(&cVar_5gr6y0Bf, 0.0f);
  numBytes += cVar_init_f(&cVar_StLU4fdM, 1.0f);
  numBytes += cIf_init(&cIf_MMN5oOG9, false);
  numBytes += cIf_init(&cIf_1oSbAOll, false);
  numBytes += cVar_init_f(&cVar_nNlEyoGH, 0.0f);
  numBytes += cVar_init_f(&cVar_C0FFNTSa, 0.0f);
  numBytes += cVar_init_f(&cVar_hxH6Smuo, 1.0f);
  numBytes += cIf_init(&cIf_M1Ll1QDf, false);
  numBytes += cIf_init(&cIf_iKgkNabo, false);
  numBytes += cVar_init_f(&cVar_Y5ecarP3, 0.0f);
  numBytes += cVar_init_f(&cVar_QJ8K3UB9, 0.0f);
  numBytes += cVar_init_f(&cVar_C57ObqvK, 60000.0f);
  numBytes += cVar_init_f(&cVar_sTbyapYy, 500.0f);
  numBytes += cSlice_init(&cSlice_klzJnQ2W, 1, -1);
  numBytes += cSlice_init(&cSlice_VYPZ4IEo, 1, -1);
  numBytes += cVar_init_f(&cVar_JNQj0sKy, 0.0f);
  numBytes += cIf_init(&cIf_X4JQc8EA, false);
  numBytes += cBinop_init(&cBinop_2Ewgk34b, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_0QXN77aL, 120.0f);
  numBytes += cBinop_init(&cBinop_7dX1UatO, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_TsZGaKgj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_SzhAlv20, 60000.0f);
  numBytes += cVar_init_f(&cVar_C5trURPI, 500.0f);
  numBytes += cSlice_init(&cSlice_IpGubuON, 1, -1);
  numBytes += cSlice_init(&cSlice_JACsOXyJ, 1, -1);
  numBytes += cVar_init_f(&cVar_TzvFcjmk, 0.0f);
  numBytes += cIf_init(&cIf_N1c28eNG, false);
  numBytes += cBinop_init(&cBinop_Yawn892V, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_xSkFpl0d, 120.0f);
  numBytes += cBinop_init(&cBinop_LuwMNLyQ, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_JCf0gSGg, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_CJfpzcVi, 60000.0f);
  numBytes += cVar_init_f(&cVar_U7L61T1o, 500.0f);
  numBytes += cSlice_init(&cSlice_mqDrh5aP, 1, -1);
  numBytes += cSlice_init(&cSlice_tIeLh5y5, 1, -1);
  numBytes += cVar_init_f(&cVar_IzM2geM2, 0.0f);
  numBytes += cIf_init(&cIf_eyP33BWZ, false);
  numBytes += cBinop_init(&cBinop_75QNcRB4, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_v99OqnTZ, 120.0f);
  numBytes += cBinop_init(&cBinop_hVYspYr6, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_CxFhFVS9, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_UirnNsyw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lxBPTc60, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wp3jadmS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HP7JYirX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E3Na4puX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_55ycLMFI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bnvHxPYx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3G6IpaMZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lrnXb0sb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2rkQ7gMC, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_tfLSvRCy);
  sEnv_free(&sEnv_55KP6IoN);
  sEnv_free(&sEnv_pC0haLX8);
  sEnv_free(&sEnv_taa6etC3);
  sEnv_free(&sEnv_lX4ULbZb);
  sEnv_free(&sEnv_odQ1LWw0);
  hTable_free(&hTable_C1M01EKC);
  hTable_free(&hTable_3diouaCx);
  hTable_free(&hTable_4QLAEMig);
  hTable_free(&hTable_F6LvdaDd);
  hTable_free(&hTable_DNYritdT);
  hTable_free(&hTable_tesrntIS);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_C1M01EKC; // del-1349-delayL
    case 0x19A00729: return &hTable_3diouaCx; // del-1349-delayR
    case 0x584C8281: return &hTable_4QLAEMig; // del-1428-delayL
    case 0x54BF59F6: return &hTable_F6LvdaDd; // del-1428-delayR
    case 0xBCE693A: return &hTable_DNYritdT; // del-1507-delayL
    case 0x95A380B3: return &hTable_tesrntIS; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6bDX6uR7_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MHkO9co3_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZwlplDF6_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YKbuY0cC_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CDV4bBYS_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dCWK3LHU_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CRrQ3LsZ_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fV5pVJXw_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RDHN9K3h_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tBLgzTLK_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kHPeG26V_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q2YSabZw_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w8H1hHXI_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KQk1WNB6_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_COyUn54i_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Il7XpjeE_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S2f7eEiO_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DMZFhPHH_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pOyRWLJH_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iMovIJWT_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u8OEwq1X_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zf3Odeqr_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iAOusC2k_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c07DpiIP_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VPyT2SDN_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ISjFR2Uv_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EelTnX5C_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q8J3zVsV_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wY8vk8ki_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yt6OHiDx_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UbkV6tgk_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_erd4Hc5K_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GPSUcwE0_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7hwyTjWo_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t5jU9UOr_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rnoYavqm_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uZJO5j4z_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vNEi5Cyn_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s0QuuQnX_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DeR3gGaR_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TAxeNlQm_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0CRUgM0s_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IGB8Ytts_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Utwjky21_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IfRxJR1q_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T7DZ17Jv_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A9Dj83tw_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UsLJvktH_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cdq2v69z_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MnCf1hvX_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_77mb2aQn_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_32lznS3N_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sje1c79Y_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fWbuFqmC_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ky3vptrI_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nSR5PB83_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mgfnvyBK_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Xs7sgA8A_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LW4SbsDn_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pPZe8Eaw_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JkOba6ub_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PLz3uVAR_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UT05hS5K_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cCvGVLsv_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_RPXKyyOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7BeNsC7f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_H8zC2EH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fyk163OM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_CM8U0isk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5PW7mOKH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_geZKhTIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2a6btTZv_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lb0O0BxD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q1gPxGyL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nR93MQpJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_9JvpjyBe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zjvZahAG, 0, m, &cSlice_zjvZahAG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UmLMiMBw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_zjvZahAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_G9AdxurW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_G9AdxurW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_vHambIEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G9AdxurW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_G9AdxurW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VPyT2SDN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6AEvqyYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kZwWSzI1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_K8ytCMD9, 0, m, &cIf_K8ytCMD9_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_K8ytCMD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3AysWiVH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_2DVnUfb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_KpbtT8YH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_e3whfCf0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_XoYMb1Su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_y9YgHKVI, HV_BINOP_POW, 0, m, &cBinop_y9YgHKVI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y9YgHKVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L8JS0AkY, 0, m, &cIf_L8JS0AkY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HaiyvYX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_bSIYlL1l_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6yc4awqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Y8aM7fZ7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_suvEvIgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2DVnUfb1, 0, m, &cIf_2DVnUfb1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y8aM7fZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2DVnUfb1, 1, m, &cIf_2DVnUfb1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e3whfCf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HaiyvYX2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KpbtT8YH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_L8JS0AkY, 0, m, &cIf_L8JS0AkY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bSIYlL1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y9YgHKVI, HV_BINOP_POW, 1, m, &cBinop_y9YgHKVI_sendMessage);
  cMsg_XoYMb1Su_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_L8JS0AkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_6SSw5Axv, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_kZwWSzI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K8ytCMD9, 1, m, &cIf_K8ytCMD9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3AysWiVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XdEGSEkV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XdEGSEkV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NZBIzGRt, HV_BINOP_EQ, 1, m, &cBinop_NZBIzGRt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kO0OXH1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CvdwgLM0, HV_BINOP_ADD, 0, m, &cBinop_CvdwgLM0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CvdwgLM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6yc4awqx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_suvEvIgg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XdEGSEkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L8JS0AkY, 1, m, &cIf_L8JS0AkY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NZBIzGRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z2B5Q3MD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_z2B5Q3MD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6SSw5Axv, m);
}

void Heavy_WSTD_DL3Y::cCast_ySLYLFt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kO0OXH1v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_CAxHm8xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6AEvqyYL, 0, m, &cVar_6AEvqyYL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Rfa7k03M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CvdwgLM0, HV_BINOP_ADD, 1, m, &cBinop_CvdwgLM0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XdEGSEkV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_XdEGSEkV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NZBIzGRt, HV_BINOP_EQ, 0, m, &cBinop_NZBIzGRt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PgvrsENs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YdDbuuyv_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Zr8SMpWK, 0, m, &cIf_Zr8SMpWK_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Zr8SMpWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WlosyWn7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_Et0VErcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_i2tbd0KO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_G57HQRm4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_VjkIxajn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dOMcAN3x, HV_BINOP_POW, 0, m, &cBinop_dOMcAN3x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dOMcAN3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7sO1sRQH, 0, m, &cIf_7sO1sRQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EiulJB0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xws6JdhJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Z8sV95xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qJxedvKP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_q9FBSgJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Et0VErcl, 0, m, &cIf_Et0VErcl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qJxedvKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Et0VErcl, 1, m, &cIf_Et0VErcl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G57HQRm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_EiulJB0N_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_i2tbd0KO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_7sO1sRQH, 0, m, &cIf_7sO1sRQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xws6JdhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dOMcAN3x, HV_BINOP_POW, 1, m, &cBinop_dOMcAN3x_sendMessage);
  cMsg_VjkIxajn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_7sO1sRQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_duFQYuJe_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5on2Oev6_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6bs30ue1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_YdDbuuyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zr8SMpWK, 1, m, &cIf_Zr8SMpWK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WlosyWn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PegZuKib, HV_BINOP_GREATER_THAN, 1, m, &cBinop_PegZuKib_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iKkRywTN, HV_BINOP_EQ, 1, m, &cBinop_iKkRywTN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XJVgjZfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_V18f7jta, HV_BINOP_ADD, 0, m, &cBinop_V18f7jta_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V18f7jta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z8sV95xc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q9FBSgJV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PegZuKib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7sO1sRQH, 1, m, &cIf_7sO1sRQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iKkRywTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DtvDIXrN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_DtvDIXrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_duFQYuJe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5on2Oev6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6bs30ue1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PRwjKCGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V18f7jta, HV_BINOP_ADD, 1, m, &cBinop_V18f7jta_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PegZuKib, HV_BINOP_GREATER_THAN, 0, m, &cBinop_PegZuKib_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iKkRywTN, HV_BINOP_EQ, 0, m, &cBinop_iKkRywTN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xBlid0Vs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XJVgjZfn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sQUj4XCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PgvrsENs, 0, m, &cVar_PgvrsENs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lbvw8vXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mt9C5ggq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_J4aZzWGV, 0, m, &cIf_J4aZzWGV_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_J4aZzWGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_X8dLUcVD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_cbvFGwWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_tKEtwG7O_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_w1spBnoo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_vEpZ3JHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_l1xvwtWy, HV_BINOP_POW, 0, m, &cBinop_l1xvwtWy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l1xvwtWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1jZq3nP8, 0, m, &cIf_1jZq3nP8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xx0e8VA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_nyUAnKqJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NbWaZKuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HqAqbbeZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NKGnJ1ZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cbvFGwWe, 0, m, &cIf_cbvFGwWe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HqAqbbeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cbvFGwWe, 1, m, &cIf_cbvFGwWe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w1spBnoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_xx0e8VA2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tKEtwG7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_1jZq3nP8, 0, m, &cIf_1jZq3nP8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nyUAnKqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l1xvwtWy, HV_BINOP_POW, 1, m, &cBinop_l1xvwtWy_sendMessage);
  cMsg_vEpZ3JHW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_1jZq3nP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_59UxGIX9, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_mt9C5ggq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J4aZzWGV, 1, m, &cIf_J4aZzWGV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_X8dLUcVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5e0H0pAD, HV_BINOP_GREATER_THAN, 1, m, &cBinop_5e0H0pAD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbzrgXKr, HV_BINOP_EQ, 1, m, &cBinop_cbzrgXKr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0Gb88o3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gflhew0J, HV_BINOP_ADD, 0, m, &cBinop_gflhew0J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gflhew0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NbWaZKuE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NKGnJ1ZW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5e0H0pAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1jZq3nP8, 1, m, &cIf_1jZq3nP8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cbzrgXKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rRiXfp9l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_rRiXfp9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_59UxGIX9, m);
}

void Heavy_WSTD_DL3Y::cCast_1fkIiOwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Gb88o3M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PNdnQEiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gflhew0J, HV_BINOP_ADD, 1, m, &cBinop_gflhew0J_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5e0H0pAD, HV_BINOP_GREATER_THAN, 0, m, &cBinop_5e0H0pAD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbzrgXKr, HV_BINOP_EQ, 0, m, &cBinop_cbzrgXKr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RTjeN1mC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lbvw8vXO, 0, m, &cVar_lbvw8vXO_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Q2rhlfkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_5N2N1hgI, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_4zRsSEqt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ufkaEtSj, 0, m, &cSlice_ufkaEtSj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3nRl5LQf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ufkaEtSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Hyh1FJq4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Hyh1FJq4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_pSRIDGyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Hyh1FJq4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Hyh1FJq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iAOusC2k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3nRl5LQf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HBlKadON, 0, m, &cSlice_HBlKadON_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9JvpjyBe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_HBlKadON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Nbs2FRKt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Nbs2FRKt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_5UYTfJx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Nbs2FRKt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Nbs2FRKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EelTnX5C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_UmLMiMBw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_e0njoGMZ, 0, m, &cSlice_e0njoGMZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_geXUR3X4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_e0njoGMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SPAhhlCV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SPAhhlCV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_McYVz5jP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SPAhhlCV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_SPAhhlCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c07DpiIP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_geXUR3X4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LVBtkiiP, 0, m, &cSlice_LVBtkiiP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_LVBtkiiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cBnrMW81_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cBnrMW81_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_V3Jq9Upj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cBnrMW81_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_cBnrMW81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ISjFR2Uv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_FUDakAxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nsV4uerq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_IW5djJYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dPLnR4QL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vqZ1hoAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YKQB8PKl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RSqmwJ7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jXHFwSib, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_V0NCEQRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gVayQMOm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_OBlRSw3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cFk3ZACR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cFk3ZACR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ismTlifP, HV_BINOP_DIVIDE, 1, m, &cBinop_ismTlifP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v3Xpo5jV_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_IAWZRXzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GWX0JFOe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6aBsgPd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_IAWZRXzL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GWX0JFOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ismTlifP, HV_BINOP_DIVIDE, 0, m, &cBinop_ismTlifP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v3Xpo5jV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6aBsgPd2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ismTlifP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0zkP2YeD, HV_BINOP_MULTIPLY, 1, m, &cBinop_0zkP2YeD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0zkP2YeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pzNSTRPz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iZMO31YG_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_7QdiG9sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B9MmL45W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_XUYOEcjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zLzhgYmZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5CtTH0tD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_h7KlKZ4E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h7KlKZ4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0zkP2YeD, HV_BINOP_MULTIPLY, 0, m, &cBinop_0zkP2YeD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9eKpxY6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_tKMyRIHa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tKMyRIHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pC5uCQsV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jHLNDNns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q5N8Ke1W, 1, m, &cVar_q5N8Ke1W_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_q5N8Ke1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KcHzBTR4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7h0ygrg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OOwiSfvT, HV_BINOP_MULTIPLY, 1, m, &cBinop_OOwiSfvT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zknfjKDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7h0ygrg6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q1doV66g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OUOKDaC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OUOKDaC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bxmws1wG, HV_BINOP_MULTIPLY, 1, m, &cBinop_bxmws1wG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cPXNfZ5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_caxZLLyE, HV_BINOP_MULTIPLY, 1, m, &cBinop_caxZLLyE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GHlj2MVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cPXNfZ5L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bJDIVhw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V9CrKshN, HV_BINOP_MULTIPLY, 1, m, &cBinop_V9CrKshN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jhcmZKcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LOvrv7ww_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LOvrv7ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q5TXqq3a, HV_BINOP_MULTIPLY, 1, m, &cBinop_q5TXqq3a_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_m3US40Fr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hOG5rYSe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_5CtTH0tD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5amzn3ID_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_GRlp1Rp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9eKpxY6S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iZMO31YG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_XUYOEcjV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pzNSTRPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_7QdiG9sx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_B9MmL45W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yt6OHiDx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_zLzhgYmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wY8vk8ki_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_8Mo3mHi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q8J3zVsV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_pC5uCQsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9UqkN1nj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9UqkN1nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T1vFAwOs, HV_BINOP_MULTIPLY, 1, m, &cBinop_T1vFAwOs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T1vFAwOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wC6Tdb6d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wC6Tdb6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8Mo3mHi1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KcHzBTR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nDPCVLdz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nDPCVLdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eeIxPlmJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vUwhzMOh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LwE8Oxuk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AajWXxb5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HARCPP9P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HMuEMuVt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OOwiSfvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FUDakAxc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bxmws1wG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IW5djJYv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_caxZLLyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vqZ1hoAL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_V9CrKshN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RSqmwJ7G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_q5TXqq3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V0NCEQRq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Sr110F5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m3US40Fr, 0, m, &cVar_m3US40Fr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_b8okfmoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GRlp1Rp1, 1, m, &cVar_GRlp1Rp1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HARCPP9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bxmws1wG, HV_BINOP_MULTIPLY, 0, m, &cBinop_bxmws1wG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AajWXxb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_caxZLLyE, HV_BINOP_MULTIPLY, 0, m, &cBinop_caxZLLyE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vUwhzMOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q5TXqq3a, HV_BINOP_MULTIPLY, 0, m, &cBinop_q5TXqq3a_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LwE8Oxuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V9CrKshN, HV_BINOP_MULTIPLY, 0, m, &cBinop_V9CrKshN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eeIxPlmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_HMuEMuVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OOwiSfvT, HV_BINOP_MULTIPLY, 0, m, &cBinop_OOwiSfvT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5amzn3ID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q5N8Ke1W, 0, m, &cVar_q5N8Ke1W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hOG5rYSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GRlp1Rp1, 0, m, &cVar_GRlp1Rp1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_niL12dqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VOKkhjXp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_d3d4Wjj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lgVH9r9P, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_U8VUXney_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TgyCRvRG, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SOjoMefx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S5iDjuYX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_A1KmCoGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gJ6STxUr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_gJ6STxUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dd4Z6CC4, HV_BINOP_DIVIDE, 1, m, &cBinop_Dd4Z6CC4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rqUwvgbU_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_VnQ1IYCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_forasvns_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1PNFq4lD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_VnQ1IYCn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_forasvns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dd4Z6CC4, HV_BINOP_DIVIDE, 0, m, &cBinop_Dd4Z6CC4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rqUwvgbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1PNFq4lD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Dd4Z6CC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ehBrUDLG, HV_BINOP_MULTIPLY, 1, m, &cBinop_ehBrUDLG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ehBrUDLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1qOxQljj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e66GhpYX_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_6AY2Uv25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X8sEJVa3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_0gI3H8Qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nYKTQXIe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bJTZ30sv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_8NyB0bBY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8NyB0bBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ehBrUDLG, HV_BINOP_MULTIPLY, 0, m, &cBinop_ehBrUDLG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eJJoivVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Wn35OQMI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Wn35OQMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u9Gsmf0T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_g9lkWLkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhBgxwXb, HV_BINOP_MULTIPLY, 1, m, &cBinop_dhBgxwXb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QzdyG0Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fPi6XtNZ, 1, m, &cVar_fPi6XtNZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fi7Jj0mO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYehTwRj, HV_BINOP_MULTIPLY, 1, m, &cBinop_UYehTwRj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZXX3WT5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_201ChDnP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_201ChDnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sAaotkrA, HV_BINOP_MULTIPLY, 1, m, &cBinop_sAaotkrA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fPi6XtNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MoL79FiM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_MLEcfNss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ssjMsxru_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_bJTZ30sv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mA8y1nUM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7mGWCI2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_eJJoivVF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1qOxQljj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_6AY2Uv25_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e66GhpYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0gI3H8Qc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_X8sEJVa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GPSUcwE0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_nYKTQXIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_erd4Hc5K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_mRy3uEUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UbkV6tgk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_u9Gsmf0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XShHGtNJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XShHGtNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8TbnSnfq, HV_BINOP_MULTIPLY, 1, m, &cBinop_8TbnSnfq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8TbnSnfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LgJduiks_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LgJduiks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mRy3uEUK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_MoL79FiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ocXFJBLW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ocXFJBLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AGB5aZi0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yY5YSvWB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w0GXpYTw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bWYBptX0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oIpa1PKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_niL12dqP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dhBgxwXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d3d4Wjj9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UYehTwRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U8VUXney_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sAaotkrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SOjoMefx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_if25DaOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7mGWCI2c, 1, m, &cVar_7mGWCI2c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_q4ZstquJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MLEcfNss, 0, m, &cVar_MLEcfNss_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mA8y1nUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fPi6XtNZ, 0, m, &cVar_fPi6XtNZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ssjMsxru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7mGWCI2c, 0, m, &cVar_7mGWCI2c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_w0GXpYTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhBgxwXb, HV_BINOP_MULTIPLY, 0, m, &cBinop_dhBgxwXb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yY5YSvWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYehTwRj, HV_BINOP_MULTIPLY, 0, m, &cBinop_UYehTwRj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AGB5aZi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sAaotkrA, HV_BINOP_MULTIPLY, 0, m, &cBinop_sAaotkrA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bWYBptX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oIpa1PKw, HV_BINOP_MULTIPLY, 0, m, &cBinop_oIpa1PKw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_93ulTV8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AlIOUUeS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SO4H7OIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nHfrXWhg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_XxP8PZVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ep8OsNgw, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Z7QVER0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OA2PzEqD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_m1V9jDJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nnoMMfhe, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6zN9LmJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1OEU1Blr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_1OEU1Blr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vMadsfy4, HV_BINOP_DIVIDE, 1, m, &cBinop_vMadsfy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E0FSDNIc_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_nb5ZSLvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_y11YLmqQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oVLepCYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_nb5ZSLvs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y11YLmqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vMadsfy4, HV_BINOP_DIVIDE, 0, m, &cBinop_vMadsfy4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_E0FSDNIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oVLepCYx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vMadsfy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W81OqNQn, HV_BINOP_MULTIPLY, 1, m, &cBinop_W81OqNQn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W81OqNQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o9qEKHEW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jyuJmBhg_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_WnmUsj9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qn3XeRNi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_X0L54zgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2REyogCQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Aol24Vz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_60CZgobp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_60CZgobp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W81OqNQn, HV_BINOP_MULTIPLY, 0, m, &cBinop_W81OqNQn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LUMwMQUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_VbczNEiP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VbczNEiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gZ0OddMe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DgvKYsAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rFTApYwf, HV_BINOP_MULTIPLY, 1, m, &cBinop_rFTApYwf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_86Kv7FlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iP7gepdR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iP7gepdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DgvKYsAS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZnSOzDbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sPMagU8n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sPMagU8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_phOIRdnQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_phOIRdnQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l5MbFvQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9s2UqUM6, HV_BINOP_MULTIPLY, 1, m, &cBinop_9s2UqUM6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bcKD7DvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NhJWPCHU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NhJWPCHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_l5MbFvQg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vyFLZT8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NMB5rSoA, 1, m, &cVar_NMB5rSoA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PtTxI6rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVMZc43S, HV_BINOP_MULTIPLY, 1, m, &cBinop_bVMZc43S_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tqN7cMNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wy6ZMKo2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wy6ZMKo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R73fKFRT, HV_BINOP_MULTIPLY, 1, m, &cBinop_R73fKFRT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_NMB5rSoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q0ujYOWM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_WhM2yYxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y2oX4zcI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Aol24Vz0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hCJyhdUX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_nR2Yp82y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_LUMwMQUA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jyuJmBhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_X0L54zgR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_o9qEKHEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_WnmUsj9o_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_qn3XeRNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rnoYavqm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_2REyogCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t5jU9UOr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_6hRBYRpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7hwyTjWo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_gZ0OddMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5vezyL0r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5vezyL0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f8v9vxcH, HV_BINOP_MULTIPLY, 1, m, &cBinop_f8v9vxcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f8v9vxcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_I7LVTJML_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I7LVTJML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6hRBYRpf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Q0ujYOWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tps7rzdK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tps7rzdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SX6qTjjU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NQott6h9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jd57TDqZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8SG3pcNS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bybSFSGy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uzA7uOXd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rFTApYwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_93ulTV8W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_phOIRdnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SO4H7OIz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9s2UqUM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XxP8PZVM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bVMZc43S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z7QVER0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_R73fKFRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m1V9jDJS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_YW1rkClZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nR2Yp82y, 1, m, &cVar_nR2Yp82y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tnTFuUNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WhM2yYxb, 0, m, &cVar_WhM2yYxb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NQott6h9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R73fKFRT, HV_BINOP_MULTIPLY, 0, m, &cBinop_R73fKFRT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Jd57TDqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVMZc43S, HV_BINOP_MULTIPLY, 0, m, &cBinop_bVMZc43S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SX6qTjjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_bybSFSGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_phOIRdnQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_phOIRdnQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uzA7uOXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rFTApYwf, HV_BINOP_MULTIPLY, 0, m, &cBinop_rFTApYwf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8SG3pcNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9s2UqUM6, HV_BINOP_MULTIPLY, 0, m, &cBinop_9s2UqUM6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hCJyhdUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NMB5rSoA, 0, m, &cVar_NMB5rSoA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Y2oX4zcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nR2Yp82y, 0, m, &cVar_nR2Yp82y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_duFQYuJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q2rhlfkJ, 1, m, &cIf_Q2rhlfkJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xE4zEFDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5N2N1hgI, m);
}

void Heavy_WSTD_DL3Y::cBinop_5on2Oev6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xE4zEFDl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6bs30ue1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q2rhlfkJ, 0, m, &cIf_Q2rhlfkJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zWZuZuBT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UAm1nyVl, 0, m, &cSlice_UAm1nyVl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zMp3jZyl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_UAm1nyVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6uvoBGVl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6uvoBGVl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_FUjhbxH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6uvoBGVl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_6uvoBGVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_s0QuuQnX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_TuJnkEyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aFpeD5tn_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qaGe96DY, 0, m, &cIf_qaGe96DY_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_qaGe96DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_oO2XlYIk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_yOuOWxVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MUEq7ly0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_U59ng8ZU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_K8XiRYDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wqZ85Fwj, HV_BINOP_POW, 0, m, &cBinop_wqZ85Fwj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wqZ85Fwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CAJqTLIO, 0, m, &cIf_CAJqTLIO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ATwzGZGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cpRvnwnm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8iH6JIhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dJ7VD3xo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Kx826wQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yOuOWxVC, 0, m, &cIf_yOuOWxVC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dJ7VD3xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yOuOWxVC, 1, m, &cIf_yOuOWxVC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U59ng8ZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ATwzGZGc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MUEq7ly0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_CAJqTLIO, 0, m, &cIf_CAJqTLIO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cpRvnwnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wqZ85Fwj, HV_BINOP_POW, 1, m, &cBinop_wqZ85Fwj_sendMessage);
  cMsg_K8XiRYDJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_CAJqTLIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_M6xarT90, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_aFpeD5tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qaGe96DY, 1, m, &cIf_qaGe96DY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oO2XlYIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5A6QFjta, HV_BINOP_GREATER_THAN, 1, m, &cBinop_5A6QFjta_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_W1nzgXun, HV_BINOP_EQ, 1, m, &cBinop_W1nzgXun_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tShXH6pZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g3x8GmJU, HV_BINOP_ADD, 0, m, &cBinop_g3x8GmJU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g3x8GmJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8iH6JIhX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kx826wQn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5A6QFjta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CAJqTLIO, 1, m, &cIf_CAJqTLIO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W1nzgXun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KJZq8kEt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KJZq8kEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_M6xarT90, m);
}

void Heavy_WSTD_DL3Y::cCast_OHBhCY2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g3x8GmJU, HV_BINOP_ADD, 1, m, &cBinop_g3x8GmJU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5A6QFjta, HV_BINOP_GREATER_THAN, 0, m, &cBinop_5A6QFjta_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_W1nzgXun, HV_BINOP_EQ, 0, m, &cBinop_W1nzgXun_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mZqy3U0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TuJnkEyo, 0, m, &cVar_TuJnkEyo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jkLLnV0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tShXH6pZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LF48vs4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yx0IhziS_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_B5Ia1xan, 0, m, &cIf_B5Ia1xan_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_B5Ia1xan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DsgLddVE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_AOPEnRGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9JRwULiZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_JX8hYJkj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_1QkLzYsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WhFQunV8, HV_BINOP_POW, 0, m, &cBinop_WhFQunV8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WhFQunV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Z9p1na2, 0, m, &cIf_0Z9p1na2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BcU3h9EV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_37pYKCNd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BOCQGD8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AOPEnRGt, 0, m, &cIf_AOPEnRGt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sOk6yFOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bHJEPkIu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bHJEPkIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AOPEnRGt, 1, m, &cIf_AOPEnRGt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JX8hYJkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_BcU3h9EV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9JRwULiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0Z9p1na2, 0, m, &cIf_0Z9p1na2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_37pYKCNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WhFQunV8, HV_BINOP_POW, 1, m, &cBinop_WhFQunV8_sendMessage);
  cMsg_1QkLzYsP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_0Z9p1na2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vbLhrbEU_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BIYWyUmU_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_qP0u2fMM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_yx0IhziS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B5Ia1xan, 1, m, &cIf_B5Ia1xan_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DsgLddVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TSMV7ffX, HV_BINOP_GREATER_THAN, 1, m, &cBinop_TSMV7ffX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CH2rEgaE, HV_BINOP_EQ, 1, m, &cBinop_CH2rEgaE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iGp8dwDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FiZCzO70, HV_BINOP_ADD, 0, m, &cBinop_FiZCzO70_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FiZCzO70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sOk6yFOj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BOCQGD8s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TSMV7ffX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Z9p1na2, 1, m, &cIf_0Z9p1na2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CH2rEgaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1lseAbYv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1lseAbYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vbLhrbEU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BIYWyUmU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_qP0u2fMM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZnbBTUC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iGp8dwDc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_YF5e8r0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FiZCzO70, HV_BINOP_ADD, 1, m, &cBinop_FiZCzO70_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TSMV7ffX, HV_BINOP_GREATER_THAN, 0, m, &cBinop_TSMV7ffX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CH2rEgaE, HV_BINOP_EQ, 0, m, &cBinop_CH2rEgaE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SNAxzfhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LF48vs4x, 0, m, &cVar_LF48vs4x_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cfLxEaI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_154Pi8CX_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_WfaHsUJM, 0, m, &cIf_WfaHsUJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_WfaHsUJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MBMRrrkR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_GNXymE4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_vEANcaY7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ZHZZQE9m_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_e0zQxL71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zi1jO487, HV_BINOP_POW, 0, m, &cBinop_Zi1jO487_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zi1jO487_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MwZZ2WIf, 0, m, &cIf_MwZZ2WIf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3wrRXPPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IdsgfE72_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yb1avfwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GNXymE4A, 0, m, &cIf_GNXymE4A_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Tx5OgSRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5RW5BdpJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5RW5BdpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GNXymE4A, 1, m, &cIf_GNXymE4A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZHZZQE9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_3wrRXPPe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vEANcaY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_MwZZ2WIf, 0, m, &cIf_MwZZ2WIf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IdsgfE72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zi1jO487, HV_BINOP_POW, 1, m, &cBinop_Zi1jO487_sendMessage);
  cMsg_e0zQxL71_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_MwZZ2WIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_n9u48uKW, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_154Pi8CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WfaHsUJM, 1, m, &cIf_WfaHsUJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MBMRrrkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lHcu7IOM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_lHcu7IOM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0f7AgvAB, HV_BINOP_EQ, 1, m, &cBinop_0f7AgvAB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vLLc28uX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PtegXVXZ, HV_BINOP_ADD, 0, m, &cBinop_PtegXVXZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PtegXVXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tx5OgSRR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yb1avfwJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lHcu7IOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MwZZ2WIf, 1, m, &cIf_MwZZ2WIf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0f7AgvAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nvVYAfvR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_nvVYAfvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_n9u48uKW, m);
}

void Heavy_WSTD_DL3Y::cCast_yIS4Azg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vLLc28uX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0EO008xH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PtegXVXZ, HV_BINOP_ADD, 1, m, &cBinop_PtegXVXZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lHcu7IOM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_lHcu7IOM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0f7AgvAB, HV_BINOP_EQ, 0, m, &cBinop_0f7AgvAB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pi78kQgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cfLxEaI8, 0, m, &cVar_cfLxEaI8_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_xY5LfiLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_WKow0uYQ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_ju6jEl2H_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eoGyAemu, 0, m, &cSlice_eoGyAemu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tLoIWBA9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_eoGyAemu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TZcSNLep_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TZcSNLep_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_IXiT00rK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TZcSNLep_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_TZcSNLep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uZJO5j4z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_tLoIWBA9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kDWweVL6, 0, m, &cSlice_kDWweVL6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zWZuZuBT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_kDWweVL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KnXvOX7y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KnXvOX7y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Z5xlp1EC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KnXvOX7y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KnXvOX7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TAxeNlQm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zMp3jZyl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PzIdl3Sy, 0, m, &cSlice_PzIdl3Sy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Qbr03Z4y_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_PzIdl3Sy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AyTNxZgR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AyTNxZgR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Vqcc5Gng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AyTNxZgR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_AyTNxZgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vNEi5Cyn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Qbr03Z4y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XjaZbYdw, 0, m, &cSlice_XjaZbYdw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_XjaZbYdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0FTiBE90_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0FTiBE90_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ZPBUUjFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0FTiBE90_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_0FTiBE90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DeR3gGaR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_BgL7yGQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_opGiacve, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fLTW281n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5hAg9a0S, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_OH5rrCn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ooVqBI9U, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TNFNcZCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2AM9LelM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_iOKtOVDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rM9KBoYO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3gLo44fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SjbfTIEI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_SjbfTIEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zBc16X76, HV_BINOP_DIVIDE, 1, m, &cBinop_zBc16X76_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_slnZ9IBt_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_musykKH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_znoWZPE4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gqiRfMyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_musykKH7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_znoWZPE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zBc16X76, HV_BINOP_DIVIDE, 0, m, &cBinop_zBc16X76_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_slnZ9IBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gqiRfMyC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zBc16X76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yOFQCiP4, HV_BINOP_MULTIPLY, 1, m, &cBinop_yOFQCiP4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yOFQCiP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SfyiLxhR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ahZdOA9P_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ByGZ9BOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aAiSRDl8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_AUCSejkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uqCMWJXY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_weoFZDIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_MgEtMzkw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MgEtMzkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yOFQCiP4, HV_BINOP_MULTIPLY, 0, m, &cBinop_yOFQCiP4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8w8r8jCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_uNCjvJe1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uNCjvJe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JxPYOOgU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aoMPiyfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E3LHPAaw, 1, m, &cVar_E3LHPAaw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_E3LHPAaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eFQKStO1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BJcmrdMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KXNZFYGl, HV_BINOP_MULTIPLY, 1, m, &cBinop_KXNZFYGl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LYrcTQwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BJcmrdMN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C4hDk5jH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NB463kRp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NB463kRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SOPGL2tL, HV_BINOP_MULTIPLY, 1, m, &cBinop_SOPGL2tL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tToBaGNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H4ySKhYd, HV_BINOP_MULTIPLY, 1, m, &cBinop_H4ySKhYd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nHgKAUnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tToBaGNY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WU5SqzAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NjCpe9yS, HV_BINOP_MULTIPLY, 1, m, &cBinop_NjCpe9yS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_88crsXL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jYIZRWZY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jYIZRWZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PX94EJky, HV_BINOP_MULTIPLY, 1, m, &cBinop_PX94EJky_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_TImns3GS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bOkn7Mjs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_weoFZDIj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ly6Y7Cyf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_SJK5Gi6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8w8r8jCR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SfyiLxhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ByGZ9BOA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ahZdOA9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_AUCSejkM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_aAiSRDl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Utwjky21_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_uqCMWJXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IGB8Ytts_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_yqYwcsNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0CRUgM0s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_JxPYOOgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_B0tClmO4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B0tClmO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XGzsLLH4, HV_BINOP_MULTIPLY, 1, m, &cBinop_XGzsLLH4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XGzsLLH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VThyqSM7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VThyqSM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yqYwcsNe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_eFQKStO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UsVO8pxX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UsVO8pxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f53tWg0d_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Id5WfFuZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XWHjI1Gv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UIfFlp9J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xmqwpXI0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Vu3MgqE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KXNZFYGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BgL7yGQQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SOPGL2tL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fLTW281n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_H4ySKhYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OH5rrCn5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NjCpe9yS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TNFNcZCc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PX94EJky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iOKtOVDu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_selcwD48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TImns3GS, 0, m, &cVar_TImns3GS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ClY4dqa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SJK5Gi6m, 1, m, &cVar_SJK5Gi6m_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UIfFlp9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H4ySKhYd, HV_BINOP_MULTIPLY, 0, m, &cBinop_H4ySKhYd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xmqwpXI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SOPGL2tL, HV_BINOP_MULTIPLY, 0, m, &cBinop_SOPGL2tL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9Vu3MgqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KXNZFYGl, HV_BINOP_MULTIPLY, 0, m, &cBinop_KXNZFYGl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XWHjI1Gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NjCpe9yS, HV_BINOP_MULTIPLY, 0, m, &cBinop_NjCpe9yS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Id5WfFuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PX94EJky, HV_BINOP_MULTIPLY, 0, m, &cBinop_PX94EJky_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f53tWg0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_ly6Y7Cyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E3LHPAaw, 0, m, &cVar_E3LHPAaw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bOkn7Mjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SJK5Gi6m, 0, m, &cVar_SJK5Gi6m_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xwrwoGGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yWj0Hgbk, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_y2Y8PsIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lE8eUZX3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NlrimeR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tswci10b, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_exfwV3IZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hfciy1kH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tMqMnk55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tgaL8rLM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tgaL8rLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gXpbApS0, HV_BINOP_DIVIDE, 1, m, &cBinop_gXpbApS0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0RpS934o_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_NOQXm3GA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ctA95AXm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AvuTfHhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_NOQXm3GA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ctA95AXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gXpbApS0, HV_BINOP_DIVIDE, 0, m, &cBinop_gXpbApS0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0RpS934o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AvuTfHhI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gXpbApS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DjvBmiRz, HV_BINOP_MULTIPLY, 1, m, &cBinop_DjvBmiRz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DjvBmiRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ULNPiYeB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ut4QLexL_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_5pT86hHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pMqJfUAW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_xpdihThL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_riBLpCnC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_e8QOSLYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_JZWwIr15_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JZWwIr15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DjvBmiRz, HV_BINOP_MULTIPLY, 0, m, &cBinop_DjvBmiRz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uNEdqce3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_5EHmDFl5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5EHmDFl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rsCEJzH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IccKm7J4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZeTrXHf8, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZeTrXHf8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OdKG2zaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aUkPnTaV, 1, m, &cVar_aUkPnTaV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pWHkGk50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d9zWfMz5, HV_BINOP_MULTIPLY, 1, m, &cBinop_d9zWfMz5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8vdr6glg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hfBoy1vu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hfBoy1vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rMnJxSRs, HV_BINOP_MULTIPLY, 1, m, &cBinop_rMnJxSRs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_aUkPnTaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mnKPUpeL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_8Om0u302_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LSe3EZk9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_e8QOSLYw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3DE88vyf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QJtdPZTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_uNEdqce3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ut4QLexL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_xpdihThL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ULNPiYeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5pT86hHr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_pMqJfUAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A9Dj83tw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_riBLpCnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_T7DZ17Jv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_g6qIjpH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IfRxJR1q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_rsCEJzH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_o7N1l3OE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o7N1l3OE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ROIPKFVU, HV_BINOP_MULTIPLY, 1, m, &cBinop_ROIPKFVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ROIPKFVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LMfCxM5I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LMfCxM5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g6qIjpH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_mnKPUpeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kyBsTaza_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kyBsTaza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gssBPtKy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JU9qSn04_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fp2XXaDd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hHCKKG2s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MIMxq6L2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xwrwoGGK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZeTrXHf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y2Y8PsIK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_d9zWfMz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NlrimeR6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rMnJxSRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_exfwV3IZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WiPERyCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Om0u302, 0, m, &cVar_8Om0u302_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6ADJqv4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QJtdPZTE, 1, m, &cVar_QJtdPZTE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3DE88vyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aUkPnTaV, 0, m, &cVar_aUkPnTaV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LSe3EZk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QJtdPZTE, 0, m, &cVar_QJtdPZTE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Fp2XXaDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZeTrXHf8, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZeTrXHf8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gssBPtKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rMnJxSRs, HV_BINOP_MULTIPLY, 0, m, &cBinop_rMnJxSRs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JU9qSn04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d9zWfMz5, HV_BINOP_MULTIPLY, 0, m, &cBinop_d9zWfMz5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hHCKKG2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MIMxq6L2, HV_BINOP_MULTIPLY, 0, m, &cBinop_MIMxq6L2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u7Yq6YBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F2HZ0jbP, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NQftbgRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tGyecyQ6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RO0MafI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bryel1eD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_srocCNrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rqxQoYkY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_62Lq2A7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8kkCvHsm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_EO0uAl4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gc01NLLj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_gc01NLLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9SU9joBI, HV_BINOP_DIVIDE, 1, m, &cBinop_9SU9joBI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NKWvzn8L_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_fA4Besi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GHFeWRPS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LjjXq7Ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_fA4Besi3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GHFeWRPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9SU9joBI, HV_BINOP_DIVIDE, 0, m, &cBinop_9SU9joBI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NKWvzn8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LjjXq7Ap_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9SU9joBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eoa9VwSW, HV_BINOP_MULTIPLY, 1, m, &cBinop_Eoa9VwSW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Eoa9VwSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oFsfiiQv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EuZfweGE_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ckykA7iw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_W97jZZFB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_hkRipbqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rMatUBEZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PURAg2cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_duhipV3S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_duhipV3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eoa9VwSW, HV_BINOP_MULTIPLY, 0, m, &cBinop_Eoa9VwSW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qZ4Z069p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_HAHm7sFx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HAHm7sFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dYNGyW1Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hyni5rb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EpC44Vpq, HV_BINOP_MULTIPLY, 1, m, &cBinop_EpC44Vpq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eXt2CXfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_N6G09P1o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_N6G09P1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hyni5rb5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BYu3WEp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_boEEGJw0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_boEEGJw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dWvKJ93J, HV_BINOP_MULTIPLY, 1, m, &cBinop_dWvKJ93J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QtwZLSme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Y1Be6q4, HV_BINOP_MULTIPLY, 1, m, &cBinop_4Y1Be6q4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BkbWL37S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BeGvTWqf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BeGvTWqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QtwZLSme_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0PATZTJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OB9sv3XN, 1, m, &cVar_OB9sv3XN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QUzwqk5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u9pkXiZa, HV_BINOP_MULTIPLY, 1, m, &cBinop_u9pkXiZa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_htikBbXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UktF6REt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UktF6REt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_47nKLezE, HV_BINOP_MULTIPLY, 1, m, &cBinop_47nKLezE_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_OB9sv3XN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IcaceCKe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Gl0axYie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0yoLbvHW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_PURAg2cy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tAuisKwP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8Dh5LaeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qZ4Z069p_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EuZfweGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_hkRipbqb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oFsfiiQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ckykA7iw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_W97jZZFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MnCf1hvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rMatUBEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cdq2v69z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_UPNN1Fi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UsLJvktH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_dYNGyW1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dcBFGTZF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dcBFGTZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1lKt6NJw, HV_BINOP_MULTIPLY, 1, m, &cBinop_1lKt6NJw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1lKt6NJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fZRGA9Vk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fZRGA9Vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UPNN1Fi8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_IcaceCKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Nkw5jXlD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nkw5jXlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H1fcBRNk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j5H9DnB5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iJGNDxOL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6q5nmPSu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zXVhYaKc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9rqq6942_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EpC44Vpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u7Yq6YBr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dWvKJ93J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NQftbgRP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4Y1Be6q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RO0MafI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_u9pkXiZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_srocCNrY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_47nKLezE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_62Lq2A7w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_wD9w5cUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gl0axYie, 0, m, &cVar_Gl0axYie_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sIcGBkaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Dh5LaeR, 1, m, &cVar_8Dh5LaeR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_j5H9DnB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_47nKLezE, HV_BINOP_MULTIPLY, 0, m, &cBinop_47nKLezE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zXVhYaKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dWvKJ93J, HV_BINOP_MULTIPLY, 0, m, &cBinop_dWvKJ93J_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9rqq6942_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EpC44Vpq, HV_BINOP_MULTIPLY, 0, m, &cBinop_EpC44Vpq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H1fcBRNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_iJGNDxOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u9pkXiZa, HV_BINOP_MULTIPLY, 0, m, &cBinop_u9pkXiZa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6q5nmPSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Y1Be6q4, HV_BINOP_MULTIPLY, 0, m, &cBinop_4Y1Be6q4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tAuisKwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OB9sv3XN, 0, m, &cVar_OB9sv3XN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0yoLbvHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Dh5LaeR, 0, m, &cVar_8Dh5LaeR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vbLhrbEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xY5LfiLw, 1, m, &cIf_xY5LfiLw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OSxzjnz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WKow0uYQ, m);
}

void Heavy_WSTD_DL3Y::cBinop_BIYWyUmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OSxzjnz6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qP0u2fMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xY5LfiLw, 0, m, &cIf_xY5LfiLw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_G4hIVrZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k0adVJbG, HV_BINOP_DIVIDE, 0, m, &cBinop_k0adVJbG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Za51Z6Cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KCQqkwAG, HV_BINOP_DIVIDE, 1, m, &cBinop_KCQqkwAG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_k0adVJbG, HV_BINOP_DIVIDE, 1, m, &cBinop_k0adVJbG_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_EQWP0Vxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xmxz6Cpk, HV_BINOP_DIVIDE, 0, m, &cBinop_xmxz6Cpk_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_yFJqURB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xmxz6Cpk, HV_BINOP_DIVIDE, 1, m, &cBinop_xmxz6Cpk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nR93MQpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KCQqkwAG, HV_BINOP_DIVIDE, 0, m, &cBinop_KCQqkwAG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_q1gPxGyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G4hIVrZ9, 0, m, &cVar_G4hIVrZ9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Lb0O0BxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Za51Z6Cv, 0, m, &cVar_Za51Z6Cv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KCQqkwAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_EQWP0Vxd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k0adVJbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_yFJqURB4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xmxz6Cpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_yJjfcsgV_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_RsH4vgov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_9E5DhmxB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AqaI8pAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_x5UmpWtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yJjfcsgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_AqaI8pAI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x5UmpWtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_RsH4vgov_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9E5DhmxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ElXXM7HK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Pz7IiZ4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ozstBjZB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_wLbom7n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z3QarxbO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_AzHckjiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DORZAuTG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_upl7LidO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uOQBgvfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_NDCK0Ko3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xi6PTMRc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_UXUyAgt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yvC0Otj5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_zqSvPUYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cn0QAG1K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_zLHlqDdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DhUDhaQJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_XJzPYWdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kYwVKVir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_bX1eWhFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zNnu075l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_khUz6vQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pIN7BUNS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_27Lh8F9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4E8ZX8Rr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_20UZzMeL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I47MFrti, 0, m, &cSlice_I47MFrti_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_I47MFrti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zsOJ2fnD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zsOJ2fnD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_5r2GFnDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zsOJ2fnD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_zsOJ2fnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sje1c79Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4qiIsMs4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_G7y1EsKP, 0, m, &cSlice_G7y1EsKP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8M8HA56z_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_G7y1EsKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iIWD01Qi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iIWD01Qi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_eeCNNVbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iIWD01Qi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_iIWD01Qi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_77mb2aQn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_n2aVdUnd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3ZLWpZYC, 0, m, &cSlice_3ZLWpZYC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_20UZzMeL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_3ZLWpZYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HEFIeQJT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HEFIeQJT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_QSwPtEPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HEFIeQJT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_HEFIeQJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fWbuFqmC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iPpdlong_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DTCAvLOv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DTCAvLOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_NNKF0hh1_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_k7gMHXEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0UBjJeyQ_sendMessage(_c, 0, m);
  cMsg_yVe0lmQX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_LCwseM59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HWKl30yp_sendMessage(_c, 0, m);
  cMsg_9A9135zN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NNKF0hh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pt4Fpaga_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pt4Fpaga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HHXkt9E7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qeh4gfVR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qeh4gfVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NLnLVnmU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_HHXkt9E7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JKPmrkF0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JKPmrkF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nEp53jN4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NLnLVnmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XaaN7AV0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XaaN7AV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UKrV84oN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nEp53jN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_k7gMHXEX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UKrV84oN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_LCwseM59_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XdBPtmLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zMcLzcXn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zMcLzcXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_atuyWmh2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_atuyWmh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jnxIX8GO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jnxIX8GO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6erFCsgl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tqOIe8gU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tqOIe8gU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pNcgjXfn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6erFCsgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gqCp5CD2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gqCp5CD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EeNnGSSO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pNcgjXfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FsHP2Rhu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FsHP2Rhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Dmq5S0Jv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Dmq5S0Jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wnan32Kl_sendMessage(_c, 0, m);
  cMsg_tXmg6GHM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_EeNnGSSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D2OXAnsh_sendMessage(_c, 0, m);
  cMsg_qJp4KatN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KU5UjesS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_lm2dcaie_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lm2dcaie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tofDzQm4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_h4DqAPWy_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_TO0s0kQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_zu4JVLKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1QBb8g4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uSpPAdG1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uSpPAdG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nj2pq9el, HV_BINOP_DIVIDE, 1, m, &cBinop_nj2pq9el_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tofDzQm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Rp4cM1N7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rp4cM1N7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jtkLSGqn, m);
}

void Heavy_WSTD_DL3Y::cMsg_HWo0AmB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GQiIpb94_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GQiIpb94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KU5UjesS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h4DqAPWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sx31WiGk, m);
}

void Heavy_WSTD_DL3Y::cBinop_zu4JVLKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Uyj0vKyb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Uyj0vKyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nj2pq9el, HV_BINOP_DIVIDE, 0, m, &cBinop_nj2pq9el_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nj2pq9el_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HWo0AmB0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Fm4CCOdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wA7KctsN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wA7KctsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NZ6X7vuv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QDoMbGCo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_AZJWbHH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_T0yJ8q7E_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XlfSSseD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TQbDkOT3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_TQbDkOT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O8XaKNFv, HV_BINOP_DIVIDE, 1, m, &cBinop_O8XaKNFv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NZ6X7vuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SpJUX4YX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SpJUX4YX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_skHSI109, m);
}

void Heavy_WSTD_DL3Y::cMsg_suV28Nqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sfXNOfUs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sfXNOfUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Fm4CCOdD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QDoMbGCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_N9BPWZfv, m);
}

void Heavy_WSTD_DL3Y::cBinop_T0yJ8q7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_WJV1tz6k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WJV1tz6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O8XaKNFv, HV_BINOP_DIVIDE, 0, m, &cBinop_O8XaKNFv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O8XaKNFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_suV28Nqp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_dCwV0CS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bbybZmvb, HV_BINOP_MULTIPLY, 0, m, &cBinop_bbybZmvb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RpvaZK4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cY4vE0MH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cY4vE0MH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CAdpDB9a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bbybZmvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6e0TVLF6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u6g2yjkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bbybZmvb, HV_BINOP_MULTIPLY, 1, m, &cBinop_bbybZmvb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CAdpDB9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_u6g2yjkY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6e0TVLF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ICuHpeJT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ICuHpeJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Zzkpx5Wv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RYWaEv3h, m);
}

void Heavy_WSTD_DL3Y::cBinop_Zzkpx5Wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pek8aLU3, m);
}

void Heavy_WSTD_DL3Y::cVar_q5Nqp00O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9JE7Lolx, HV_BINOP_MULTIPLY, 0, m, &cBinop_9JE7Lolx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9FWhV4e9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZVzOyXeR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ZVzOyXeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EZxKdYRr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9JE7Lolx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_59KTyj60_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VrGc1B1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9JE7Lolx, HV_BINOP_MULTIPLY, 1, m, &cBinop_9JE7Lolx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EZxKdYRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VrGc1B1t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_59KTyj60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ajLaUzlP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ajLaUzlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JFxrlh0x_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OZQWpaI0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JFxrlh0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qYVbZbpp, m);
}

void Heavy_WSTD_DL3Y::sEnv_tfLSvRCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BJwV33xG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_69uvfVQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_YdBth31i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_8ANBSGgE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_AC5pwTIR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_NxVGzLdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9f7fRbLN, HV_BINOP_POW, 0, m, &cBinop_9f7fRbLN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9f7fRbLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c3GXQ7QB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_V97lmY7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vRad2qLH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_69uvfVQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YdBth31i, 0, m, &cIf_YdBth31i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BJwV33xG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DD0tc8id_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DD0tc8id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YdBth31i, 1, m, &cIf_YdBth31i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AC5pwTIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_V97lmY7X_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8ANBSGgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_c3GXQ7QB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vRad2qLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9f7fRbLN, HV_BINOP_POW, 1, m, &cBinop_9f7fRbLN_sendMessage);
  cMsg_NxVGzLdh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_xOAs8MeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q6ThVeat, HV_BINOP_MULTIPLY, 0, m, &cBinop_q6ThVeat_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wjmpl5ZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_d5fYBKLq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_d5fYBKLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kvO5riVb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_q6ThVeat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zEyFzwfG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pnnFrf9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q6ThVeat, HV_BINOP_MULTIPLY, 1, m, &cBinop_q6ThVeat_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kvO5riVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pnnFrf9T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zEyFzwfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_H0IplrSS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H0IplrSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_daCGMEv1_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PyRPJVuT, m);
}

void Heavy_WSTD_DL3Y::cBinop_daCGMEv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_14ZPZnd8, m);
}

void Heavy_WSTD_DL3Y::cMsg_c3GXQ7QB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MxtT4nlP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MxtT4nlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dWlyBku3, m);
}

void Heavy_WSTD_DL3Y::sEnv_55KP6IoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vnmsml5n_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gCtcxbie_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_87uBwI4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WeLfUY1V_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_TLmbCqyk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_oLekfxBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NC1Ko4xQ, HV_BINOP_POW, 0, m, &cBinop_NC1Ko4xQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NC1Ko4xQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zfFhGBOl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SVLqBexD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Ta0XLCar_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Vnmsml5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vT0tYaV5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gCtcxbie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_87uBwI4b, 0, m, &cIf_87uBwI4b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vT0tYaV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_87uBwI4b, 1, m, &cIf_87uBwI4b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TLmbCqyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_SVLqBexD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WeLfUY1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_zfFhGBOl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ta0XLCar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NC1Ko4xQ, HV_BINOP_POW, 1, m, &cBinop_NC1Ko4xQ_sendMessage);
  cMsg_oLekfxBM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Sk8hEjxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ntCJYLk8, HV_BINOP_MULTIPLY, 0, m, &cBinop_ntCJYLk8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_COYar3UU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WBhIu11y_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WBhIu11y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SPux97v9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ntCJYLk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XtPF7xru_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yUkZ5TdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ntCJYLk8, HV_BINOP_MULTIPLY, 1, m, &cBinop_ntCJYLk8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SPux97v9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yUkZ5TdS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XtPF7xru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KoS7ZXH6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KoS7ZXH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kIDZwvNT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_l2zoK9xY, m);
}

void Heavy_WSTD_DL3Y::cBinop_kIDZwvNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_L3YdiH04, m);
}

void Heavy_WSTD_DL3Y::cMsg_zfFhGBOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_i4V99Hgw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i4V99Hgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3zAt7r5c, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8M8HA56z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UCXsT1mP, 0, m, &cSlice_UCXsT1mP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_n2aVdUnd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_UCXsT1mP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gc0fGo74_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gc0fGo74_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_hhZ7SzXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gc0fGo74_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_gc0fGo74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_32lznS3N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_EULYJkLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ql4WaQVB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ql4WaQVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9sX81D8a_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_YiYmx5Eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YiYmx5Eg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yRYZcgnN, 0, m, &cDelay_yRYZcgnN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YiYmx5Eg, 0, m, &cDelay_YiYmx5Eg_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_yVYXdgmK, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_yRYZcgnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yRYZcgnN, m);
  cMsg_LNCUZbSq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_MUbbUboP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_3sdWjVjc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_nwP0HGXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BK5eZ1cI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_C1M01EKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I8YoQB8K_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YiYmx5Eg, 2, m, &cDelay_YiYmx5Eg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FW3QLI2h_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BK5eZ1cI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_C1M01EKC, 0, m, &hTable_C1M01EKC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9sX81D8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_nwP0HGXv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LNCUZbSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_C1M01EKC, 0, m, &hTable_C1M01EKC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FW3QLI2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YiYmx5Eg, 0, m, &cDelay_YiYmx5Eg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I8YoQB8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_yRYZcgnN, 2, m, &cDelay_yRYZcgnN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3sdWjVjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_yVYXdgmK, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_JiTHS9b2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQHztwPx, HV_BINOP_SUBTRACT, 0, m, &cBinop_rQHztwPx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NBOr9unK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_a15nq4gx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_a15nq4gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MxqZfbso_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QCRVe9xj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QlfL6ma2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_Y0E8Q3df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y0E8Q3df, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2t3fQCiS, 0, m, &cDelay_2t3fQCiS_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9cFKXxWJ, 0, m, &sTabread_9cFKXxWJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_2t3fQCiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2t3fQCiS, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9cFKXxWJ, 0, m, &sTabread_9cFKXxWJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2t3fQCiS, 0, m, &cDelay_2t3fQCiS_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_9cFKXxWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_QS9yz47a, HV_BINOP_SUBTRACT, 0, m, &cBinop_QS9yz47a_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_DGqrMahT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tIULSN37, HV_BINOP_MAX, 0, m, &cBinop_tIULSN37_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MxqZfbso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DGqrMahT, HV_BINOP_MULTIPLY, 0, m, &cBinop_DGqrMahT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rQHztwPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jj4QghIy_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9cFKXxWJ, 0, m, &sTabread_9cFKXxWJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cZl0Zgqh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_BITLZNHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QS9yz47a, HV_BINOP_SUBTRACT, 1, m, &cBinop_QS9yz47a_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2t3fQCiS, 2, m, &cDelay_2t3fQCiS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QlfL6ma2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BITLZNHR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Jj4QghIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y0E8Q3df, 0, m, &cDelay_Y0E8Q3df_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2t3fQCiS, 0, m, &cDelay_2t3fQCiS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MfIDGqae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_tIULSN37, HV_BINOP_MAX, 1, m, &cBinop_tIULSN37_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tIULSN37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQHztwPx, HV_BINOP_SUBTRACT, 1, m, &cBinop_rQHztwPx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cZl0Zgqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y0E8Q3df, 0, m, &cDelay_Y0E8Q3df_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VazRNb1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y0E8Q3df, 2, m, &cDelay_Y0E8Q3df_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QS9yz47a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VazRNb1Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lDSYe8PG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QCRVe9xj, 0, m, &cVar_QCRVe9xj_sendMessage);
  cMsg_NBOr9unK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JiTHS9b2, 0, m, &cTabhead_JiTHS9b2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I8ZfmG68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S0nAWWFd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_S0nAWWFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yBoBZEw4_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_9j9cvOhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9j9cvOhp, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Op88u6S7, 0, m, &cDelay_Op88u6S7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9j9cvOhp, 0, m, &cDelay_9j9cvOhp_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SmPzUxpL, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_Op88u6S7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Op88u6S7, m);
  cMsg_6fqJfv6y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_o2MpsTbX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_7Syyu3CG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_f61NOI8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XBQu47RQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_3diouaCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AKWH7t6i_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9j9cvOhp, 2, m, &cDelay_9j9cvOhp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sIbJMCcW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XBQu47RQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_3diouaCx, 0, m, &hTable_3diouaCx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yBoBZEw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_f61NOI8j_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6fqJfv6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_3diouaCx, 0, m, &hTable_3diouaCx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sIbJMCcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9j9cvOhp, 0, m, &cDelay_9j9cvOhp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AKWH7t6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Op88u6S7, 2, m, &cDelay_Op88u6S7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7Syyu3CG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SmPzUxpL, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_8ijs9hwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r4SvlNtJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_r4SvlNtJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_J4r2hFEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Y2Fd7Sea_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Y2Fd7Sea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_p2UvlXaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_XHVzo0WA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ibPkGZ8J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_XW6kGLKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XW6kGLKy, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zp4G1bk8, 0, m, &cDelay_zp4G1bk8_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_vWg9xjYC, 0, m, &sTabread_vWg9xjYC_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_zp4G1bk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zp4G1bk8, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_vWg9xjYC, 0, m, &sTabread_vWg9xjYC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zp4G1bk8, 0, m, &cDelay_zp4G1bk8_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_vWg9xjYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_j7x0Bbev, HV_BINOP_SUBTRACT, 0, m, &cBinop_j7x0Bbev_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_ezaN5XMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bCGG9T6B, HV_BINOP_MAX, 0, m, &cBinop_bCGG9T6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p2UvlXaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ezaN5XMn, HV_BINOP_MULTIPLY, 0, m, &cBinop_ezaN5XMn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r4SvlNtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PevyANSX_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_vWg9xjYC, 0, m, &sTabread_vWg9xjYC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_53AxASuG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_S655qF82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j7x0Bbev, HV_BINOP_SUBTRACT, 1, m, &cBinop_j7x0Bbev_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zp4G1bk8, 2, m, &cDelay_zp4G1bk8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ibPkGZ8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S655qF82_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PevyANSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XW6kGLKy, 0, m, &cDelay_XW6kGLKy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zp4G1bk8, 0, m, &cDelay_zp4G1bk8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KgfWnxYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_bCGG9T6B, HV_BINOP_MAX, 1, m, &cBinop_bCGG9T6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bCGG9T6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r4SvlNtJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_r4SvlNtJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_53AxASuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XW6kGLKy, 0, m, &cDelay_XW6kGLKy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7Il9aBcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XW6kGLKy, 2, m, &cDelay_XW6kGLKy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j7x0Bbev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7Il9aBcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_slouxSJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XHVzo0WA, 0, m, &cVar_XHVzo0WA_sendMessage);
  cMsg_J4r2hFEo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8ijs9hwY, 0, m, &cTabhead_8ijs9hwY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0UBjJeyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1JYytvCh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HWKl30yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LOR5GWii, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9A9135zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CeKf1w9K, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_yVe0lmQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zD2bQONr, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qJp4KatN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZDtrzvZ7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wnan32Kl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hd762wSD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_D2OXAnsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_skU88LJ9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tXmg6GHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yzEumBOQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Y1RtrBII_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EQULPBCg, 0, m, &cSlice_EQULPBCg_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_EQULPBCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_k4k6bsAS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_k4k6bsAS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_3yifbHA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_k4k6bsAS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_k4k6bsAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mgfnvyBK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_5o2v7end_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1AkSq7iB, 0, m, &cSlice_1AkSq7iB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aiPj4V41_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_1AkSq7iB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oI0Mfvjn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oI0Mfvjn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_e6ar8BTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oI0Mfvjn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_oI0Mfvjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ky3vptrI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_OkH8tvnu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wHq9SPRr, 0, m, &cSlice_wHq9SPRr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Y1RtrBII_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_wHq9SPRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_avK1WJWP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_avK1WJWP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_d6r7N2ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_avK1WJWP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_avK1WJWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Xs7sgA8A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rPCFlLwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1T6CHbuA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1T6CHbuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_F87HlD7s_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_OfdO1hFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bwdvoKeR_sendMessage(_c, 0, m);
  cMsg_nvkeh3Qw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_qo0RK8Mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fzuGE7Cw_sendMessage(_c, 0, m);
  cMsg_qaCp0FaU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_F87HlD7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vg7bLkqp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vg7bLkqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N1LV3tYr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NI968h2r_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NI968h2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wG36dKmA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_N1LV3tYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iEj2Uk2B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iEj2Uk2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JMTBoNrj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wG36dKmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EEvHdXwN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EEvHdXwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xCOaVVIH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JMTBoNrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_OfdO1hFB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xCOaVVIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_qo0RK8Mh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SrAIX3hR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vEdtRWVK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vEdtRWVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_sozi26G6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sozi26G6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6CSHP1mH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6CSHP1mH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zzgmvKfx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3Va7ARB8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zzgmvKfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UaroBCmf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3Va7ARB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wm9R0QCa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UaroBCmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_51y0QK3d_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Wm9R0QCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9YTyBvyB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9YTyBvyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HrxtBJRA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HrxtBJRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nREMRSi8_sendMessage(_c, 0, m);
  cMsg_tbQIR6LZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_51y0QK3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2QqtnW7y_sendMessage(_c, 0, m);
  cMsg_qMjHOawp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ncC6XU7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rNlDKsOp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rNlDKsOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GdAfCJzF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FcM0h2xr_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_vlwpPazn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_hGbRpBs3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nT9Nw40x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kq29BlIR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_kq29BlIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BSsI2AEt, HV_BINOP_DIVIDE, 1, m, &cBinop_BSsI2AEt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GdAfCJzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZpV4lzW2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZpV4lzW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EHMnHpFk, m);
}

void Heavy_WSTD_DL3Y::cMsg_IXVVZbgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_esjgW3Ds_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_esjgW3Ds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ncC6XU7i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FcM0h2xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dad4jLYG, m);
}

void Heavy_WSTD_DL3Y::cBinop_hGbRpBs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_UMORaUB0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UMORaUB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BSsI2AEt, HV_BINOP_DIVIDE, 0, m, &cBinop_BSsI2AEt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BSsI2AEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IXVVZbgP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_E1LJ3mYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_x2xM5nNr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x2xM5nNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nzKmvEaY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kAlyQf10_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QVgfR36H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_UoYz5owO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_x6fcIrfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LG9TqWnZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_LG9TqWnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8XVcdy7Y, HV_BINOP_DIVIDE, 1, m, &cBinop_8XVcdy7Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nzKmvEaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Mrwh6IxX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Mrwh6IxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EsNytzSR, m);
}

void Heavy_WSTD_DL3Y::cMsg_xKyKMucz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FpH4ODxC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FpH4ODxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_E1LJ3mYm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kAlyQf10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nBK5Q9GP, m);
}

void Heavy_WSTD_DL3Y::cBinop_UoYz5owO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_PWtNJ0M2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PWtNJ0M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8XVcdy7Y, HV_BINOP_DIVIDE, 0, m, &cBinop_8XVcdy7Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8XVcdy7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xKyKMucz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_XLNCODwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rht77Iz5, HV_BINOP_MULTIPLY, 0, m, &cBinop_Rht77Iz5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_owOsmxtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ME0HG24d_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ME0HG24d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E1UOUDAn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Rht77Iz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4BI7o65x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s2zP6xSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rht77Iz5, HV_BINOP_MULTIPLY, 1, m, &cBinop_Rht77Iz5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_E1UOUDAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_s2zP6xSL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4BI7o65x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_bFWVhRtS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bFWVhRtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7azz8DNq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8rm93nrG, m);
}

void Heavy_WSTD_DL3Y::cBinop_7azz8DNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6bm6zYOo, m);
}

void Heavy_WSTD_DL3Y::cVar_SXbN6DTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r2JLubuE, HV_BINOP_MULTIPLY, 0, m, &cBinop_r2JLubuE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6u22RqjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wIxH2ntf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_wIxH2ntf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ezjwAygI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_r2JLubuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_tp92Y5gC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_itBfzzEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r2JLubuE, HV_BINOP_MULTIPLY, 1, m, &cBinop_r2JLubuE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ezjwAygI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_itBfzzEP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tp92Y5gC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MjakfcK5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MjakfcK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_R0hzulBB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_noaOPQBm, m);
}

void Heavy_WSTD_DL3Y::cBinop_R0hzulBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tGhZiupz, m);
}

void Heavy_WSTD_DL3Y::sEnv_pC0haLX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aOrLamKQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cUsT1XT8_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_kPwISEjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ktntiYYT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_TiXcZcqD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_IA4fkxaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_p3IFL9JI, HV_BINOP_POW, 0, m, &cBinop_p3IFL9JI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p3IFL9JI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pnj5ARTZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gnKfh6jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_kGfHaqaz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cUsT1XT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kPwISEjR, 0, m, &cIf_kPwISEjR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aOrLamKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5DJ679pU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5DJ679pU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kPwISEjR, 1, m, &cIf_kPwISEjR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TiXcZcqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gnKfh6jr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ktntiYYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_pnj5ARTZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kGfHaqaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p3IFL9JI, HV_BINOP_POW, 1, m, &cBinop_p3IFL9JI_sendMessage);
  cMsg_IA4fkxaR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_frTIvtwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_12inedSY, HV_BINOP_MULTIPLY, 0, m, &cBinop_12inedSY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_c6mD0EMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JgSHpS1m_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JgSHpS1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TBLjZeTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_12inedSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KOKOfKxL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UgvXXmIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_12inedSY, HV_BINOP_MULTIPLY, 1, m, &cBinop_12inedSY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TBLjZeTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UgvXXmIi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KOKOfKxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_iCVIBARe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iCVIBARe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xbIl5ZMe_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uEPVgiph, m);
}

void Heavy_WSTD_DL3Y::cBinop_xbIl5ZMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fkQJci3v, m);
}

void Heavy_WSTD_DL3Y::cMsg_pnj5ARTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sVPA1rjy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sVPA1rjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4Gbu39bu, m);
}

void Heavy_WSTD_DL3Y::sEnv_taa6etC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xg4D8mN5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5baJsQYH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_vi3MxSOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_dzuIdjJh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_sPuZkXPa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_aGUAHSit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9bSLrCXR, HV_BINOP_POW, 0, m, &cBinop_9bSLrCXR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9bSLrCXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ddGYWFEz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_H8l8Sw2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Zg5Svm1a_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xg4D8mN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_f0rXuMrY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5baJsQYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vi3MxSOq, 0, m, &cIf_vi3MxSOq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f0rXuMrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vi3MxSOq, 1, m, &cIf_vi3MxSOq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sPuZkXPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_H8l8Sw2g_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dzuIdjJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_ddGYWFEz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Zg5Svm1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9bSLrCXR, HV_BINOP_POW, 1, m, &cBinop_9bSLrCXR_sendMessage);
  cMsg_aGUAHSit_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_eWUAFDJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dcwRl2Am, HV_BINOP_MULTIPLY, 0, m, &cBinop_dcwRl2Am_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bUEdngDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FhFc5HI4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_FhFc5HI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tr1TeHKj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dcwRl2Am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Iz7YNqtU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NloElC4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dcwRl2Am, HV_BINOP_MULTIPLY, 1, m, &cBinop_dcwRl2Am_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tr1TeHKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NloElC4m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Iz7YNqtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_htrlTbZ0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_htrlTbZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_4Eb4NlXB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ObrkNkPi, m);
}

void Heavy_WSTD_DL3Y::cBinop_4Eb4NlXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_L7VNmyLZ, m);
}

void Heavy_WSTD_DL3Y::cMsg_ddGYWFEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hhuOmCbF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hhuOmCbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1M7sNqMW, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_aiPj4V41_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_i2UhBaJ7, 0, m, &cSlice_i2UhBaJ7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OkH8tvnu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_i2UhBaJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_u7JMzcO1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_u7JMzcO1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_axcj3w7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_u7JMzcO1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_u7JMzcO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nSR5PB83_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_I3nMMid0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7U8k3F74_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7U8k3F74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5dp98WeS_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_AebW6Lr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AebW6Lr9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xdFTMbW9, 0, m, &cDelay_xdFTMbW9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AebW6Lr9, 0, m, &cDelay_AebW6Lr9_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ktViRj5c, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_xdFTMbW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xdFTMbW9, m);
  cMsg_HLIUy2MA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ettBqo38_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_snTOD50H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_UDVsbcOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cU43y9fP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_4QLAEMig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bl7gb1ub_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AebW6Lr9, 2, m, &cDelay_AebW6Lr9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CfEl6tPL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cU43y9fP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_4QLAEMig, 0, m, &hTable_4QLAEMig_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5dp98WeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_UDVsbcOb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HLIUy2MA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_4QLAEMig, 0, m, &hTable_4QLAEMig_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CfEl6tPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AebW6Lr9, 0, m, &cDelay_AebW6Lr9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bl7gb1ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xdFTMbW9, 2, m, &cDelay_xdFTMbW9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_snTOD50H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ktViRj5c, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_RcJsIeiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7WZd74cV, HV_BINOP_SUBTRACT, 0, m, &cBinop_7WZd74cV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yJAuXXyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jGvmux01_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_jGvmux01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6AYm4JHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bvuPeikZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rEIYUjuT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_Ho6Fytjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ho6Fytjm, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ol7jg8Dc, 0, m, &cDelay_ol7jg8Dc_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hxDx1eyJ, 0, m, &sTabread_hxDx1eyJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ol7jg8Dc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ol7jg8Dc, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hxDx1eyJ, 0, m, &sTabread_hxDx1eyJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ol7jg8Dc, 0, m, &cDelay_ol7jg8Dc_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_hxDx1eyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DDD6DDas, HV_BINOP_SUBTRACT, 0, m, &cBinop_DDD6DDas_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_nZ2V9UTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KImkklxD, HV_BINOP_MAX, 0, m, &cBinop_KImkklxD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6AYm4JHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nZ2V9UTq, HV_BINOP_MULTIPLY, 0, m, &cBinop_nZ2V9UTq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7WZd74cV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8FJe9wT7_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_hxDx1eyJ, 0, m, &sTabread_hxDx1eyJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wNxBhrhg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cak2tbo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DDD6DDas, HV_BINOP_SUBTRACT, 1, m, &cBinop_DDD6DDas_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ol7jg8Dc, 2, m, &cDelay_ol7jg8Dc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rEIYUjuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cak2tbo2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8FJe9wT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ho6Fytjm, 0, m, &cDelay_Ho6Fytjm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ol7jg8Dc, 0, m, &cDelay_ol7jg8Dc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u4rEgqrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_KImkklxD, HV_BINOP_MAX, 1, m, &cBinop_KImkklxD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KImkklxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7WZd74cV, HV_BINOP_SUBTRACT, 1, m, &cBinop_7WZd74cV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wNxBhrhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ho6Fytjm, 0, m, &cDelay_Ho6Fytjm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CAepIlKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ho6Fytjm, 2, m, &cDelay_Ho6Fytjm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DDD6DDas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CAepIlKL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ySHu0WTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bvuPeikZ, 0, m, &cVar_bvuPeikZ_sendMessage);
  cMsg_yJAuXXyz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RcJsIeiH, 0, m, &cTabhead_RcJsIeiH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LVE6SNor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_W841ixIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_W841ixIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6K1Oza5M_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_fzj2a77r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fzj2a77r, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ab54VjFI, 0, m, &cDelay_ab54VjFI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fzj2a77r, 0, m, &cDelay_fzj2a77r_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Xy6G5mBv, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_ab54VjFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ab54VjFI, m);
  cMsg_PMImyJKs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_GlclQbXp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_GfZWj7kW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_ZpVBRDJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5BBdhXxJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_F6LvdaDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lA9COjIE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fzj2a77r, 2, m, &cDelay_fzj2a77r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wi1rwHOQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5BBdhXxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_F6LvdaDd, 0, m, &hTable_F6LvdaDd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6K1Oza5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_ZpVBRDJn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PMImyJKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_F6LvdaDd, 0, m, &hTable_F6LvdaDd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wi1rwHOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fzj2a77r, 0, m, &cDelay_fzj2a77r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lA9COjIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ab54VjFI, 2, m, &cDelay_ab54VjFI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GfZWj7kW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Xy6G5mBv, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_9tMTbkXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BSeWEdJX, HV_BINOP_SUBTRACT, 0, m, &cBinop_BSeWEdJX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MfmH7WeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YPFidK0s_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_YPFidK0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aFFQQObR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_vSzkcySE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r9TJLrZ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_YcJhrBHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YcJhrBHT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_McO6x1Hn, 0, m, &cDelay_McO6x1Hn_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Y3KqbIuB, 0, m, &sTabread_Y3KqbIuB_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_McO6x1Hn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_McO6x1Hn, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Y3KqbIuB, 0, m, &sTabread_Y3KqbIuB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_McO6x1Hn, 0, m, &cDelay_McO6x1Hn_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_Y3KqbIuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_bPJgWqDk, HV_BINOP_SUBTRACT, 0, m, &cBinop_bPJgWqDk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_84ywi2q3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uYbzT9gl, HV_BINOP_MAX, 0, m, &cBinop_uYbzT9gl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aFFQQObR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_84ywi2q3, HV_BINOP_MULTIPLY, 0, m, &cBinop_84ywi2q3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BSeWEdJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DSlcVNhD_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Y3KqbIuB, 0, m, &sTabread_Y3KqbIuB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZmzYPp3y_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_djDIuYs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bPJgWqDk, HV_BINOP_SUBTRACT, 1, m, &cBinop_bPJgWqDk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_McO6x1Hn, 2, m, &cDelay_McO6x1Hn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_r9TJLrZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_djDIuYs4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DSlcVNhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YcJhrBHT, 0, m, &cDelay_YcJhrBHT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_McO6x1Hn, 0, m, &cDelay_McO6x1Hn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ECEX9iX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_uYbzT9gl, HV_BINOP_MAX, 1, m, &cBinop_uYbzT9gl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uYbzT9gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BSeWEdJX, HV_BINOP_SUBTRACT, 1, m, &cBinop_BSeWEdJX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZmzYPp3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YcJhrBHT, 0, m, &cDelay_YcJhrBHT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xvuw8w5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YcJhrBHT, 2, m, &cDelay_YcJhrBHT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bPJgWqDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xvuw8w5A_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QYOvR1rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vSzkcySE, 0, m, &cVar_vSzkcySE_sendMessage);
  cMsg_MfmH7WeR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_9tMTbkXc, 0, m, &cTabhead_9tMTbkXc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bwdvoKeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XWI1IyDr, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fzuGE7Cw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YhgjhRjv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qaCp0FaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jza4JCsW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nvkeh3Qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0angkyHi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qMjHOawp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c2Rc1CcA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nREMRSi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pjIOgGQ4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2QqtnW7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OHWFhFQT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tbQIR6LZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mBX0svRQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_E8kffuLt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zlYVsVbr, 0, m, &cSlice_zlYVsVbr_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_zlYVsVbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7jC92B9q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7jC92B9q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_9BAYDLNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7jC92B9q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7jC92B9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JkOba6ub_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_yAKcMYpL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jrd693Np, 0, m, &cSlice_jrd693Np_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7NVrQG9L_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_jrd693Np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RQSJujIV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RQSJujIV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_nuINDAUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RQSJujIV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_RQSJujIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LW4SbsDn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_QWPbLb4X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_00Suq8Pa, 0, m, &cSlice_00Suq8Pa_sendMessage);
      break;
    }
    default: {
      cSwitchcase_E8kffuLt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_00Suq8Pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mIw49xT7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mIw49xT7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_lSJH5rFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mIw49xT7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_mIw49xT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PLz3uVAR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KJZkGDdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SPhT9eiL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SPhT9eiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vsJ9roDF_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_4zenr5MY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F2wKhlhY_sendMessage(_c, 0, m);
  cMsg_PhOelZeb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_yPawRPRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dx3GqbDG_sendMessage(_c, 0, m);
  cMsg_sLVsZaIe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vsJ9roDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Q0ERvNCi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q0ERvNCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m5sx8ytR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dOfXFifY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dOfXFifY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m9ldb891_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_m5sx8ytR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_hOhpue1a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hOhpue1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Orprrkv9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m9ldb891_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PcYkA48h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PcYkA48h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gFfYVJu4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Orprrkv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_4zenr5MY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gFfYVJu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_yPawRPRK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZwOfChlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rO74kNZA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rO74kNZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_LdU4GNA8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LdU4GNA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_R5vtkj34_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R5vtkj34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JlPCfDAQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9O725zKl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9O725zKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eZtW2eEk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JlPCfDAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EuPt9eKt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EuPt9eKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zm38aX9D_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eZtW2eEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9y94DdBu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9y94DdBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_laBFQZC7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_laBFQZC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L8v6K7pd_sendMessage(_c, 0, m);
  cMsg_JhsXUzVt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zm38aX9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w2s2VPXQ_sendMessage(_c, 0, m);
  cMsg_yX1a19Pm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BNxPDvU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_khOLLkwQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_khOLLkwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_guB29Mtn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3kLl7PhJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_HExhlo9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_1ilseiFi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_g8DgLH0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RufMujUp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RufMujUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ak2HSnIm, HV_BINOP_DIVIDE, 1, m, &cBinop_ak2HSnIm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_guB29Mtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zaSpQql5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zaSpQql5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pCtS5Ub7, m);
}

void Heavy_WSTD_DL3Y::cMsg_tQyWlyWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Rawn9hVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rawn9hVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BNxPDvU9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3kLl7PhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iSDBH07R, m);
}

void Heavy_WSTD_DL3Y::cBinop_1ilseiFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Ue9mw4ty_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ue9mw4ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ak2HSnIm, HV_BINOP_DIVIDE, 0, m, &cBinop_ak2HSnIm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ak2HSnIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tQyWlyWz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4s643Fdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0d8FWeLo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0d8FWeLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NcCLSZRp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xdv0TmQV_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_APBEyypz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_nlntbnuU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tuBv6agx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xbf83QX2_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xbf83QX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MwjmydF4, HV_BINOP_DIVIDE, 1, m, &cBinop_MwjmydF4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NcCLSZRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nWmAgfda_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nWmAgfda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_aLXQHzo8, m);
}

void Heavy_WSTD_DL3Y::cMsg_G8wQ47u7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UJz43GfK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UJz43GfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4s643Fdh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xdv0TmQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4U9gcFBv, m);
}

void Heavy_WSTD_DL3Y::cBinop_nlntbnuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_au4jb8Ct_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_au4jb8Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MwjmydF4, HV_BINOP_DIVIDE, 0, m, &cBinop_MwjmydF4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MwjmydF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G8wQ47u7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_K5UJrBEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J2hsTXRU, HV_BINOP_MULTIPLY, 0, m, &cBinop_J2hsTXRU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fUbo9TQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0S67syfE_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_0S67syfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TPGpu8Xx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_J2hsTXRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_tH4bJ4ul_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LhhfWuy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J2hsTXRU, HV_BINOP_MULTIPLY, 1, m, &cBinop_J2hsTXRU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TPGpu8Xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LhhfWuy2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tH4bJ4ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Gd7PcDF8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Gd7PcDF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_acEUI4hC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TXimwrM2, m);
}

void Heavy_WSTD_DL3Y::cBinop_acEUI4hC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8ejYyDhg, m);
}

void Heavy_WSTD_DL3Y::cVar_j3PXL7fR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_acGh7s1y, HV_BINOP_MULTIPLY, 0, m, &cBinop_acGh7s1y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Uh5n635q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7C8eEOL6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7C8eEOL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s6XwtnFi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_acGh7s1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_blMMCq3X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d56fAlFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_acGh7s1y, HV_BINOP_MULTIPLY, 1, m, &cBinop_acGh7s1y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s6XwtnFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_d56fAlFp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_blMMCq3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7zA4RAlI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7zA4RAlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pSRerEx4_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_J8GQdxlw, m);
}

void Heavy_WSTD_DL3Y::cBinop_pSRerEx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_o28JgQuI, m);
}

void Heavy_WSTD_DL3Y::sEnv_lX4ULbZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FRX4YN51_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AkOECPYp_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_bsBDNogO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_AGKteqH6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_z4d3mrdd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_KNbgpVSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_q7hrarpB, HV_BINOP_POW, 0, m, &cBinop_q7hrarpB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q7hrarpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rETiC2ki_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7yKY2sre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Ng84NiSt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FRX4YN51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Sjt5dYMs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AkOECPYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bsBDNogO, 0, m, &cIf_bsBDNogO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sjt5dYMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bsBDNogO, 1, m, &cIf_bsBDNogO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z4d3mrdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_7yKY2sre_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AGKteqH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_rETiC2ki_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ng84NiSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q7hrarpB, HV_BINOP_POW, 1, m, &cBinop_q7hrarpB_sendMessage);
  cMsg_KNbgpVSs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_7JXDPl2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3QarwxNp, HV_BINOP_MULTIPLY, 0, m, &cBinop_3QarwxNp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fbY06aRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_l9BR2Kdk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_l9BR2Kdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oVkiua0J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3QarwxNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KZ9GN8va_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JeO5ov27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3QarwxNp, HV_BINOP_MULTIPLY, 1, m, &cBinop_3QarwxNp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oVkiua0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JeO5ov27_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KZ9GN8va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GKRW8e8n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GKRW8e8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_h8CXBCyS_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_f2wrFm8M, m);
}

void Heavy_WSTD_DL3Y::cBinop_h8CXBCyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CUqx9Jid, m);
}

void Heavy_WSTD_DL3Y::cMsg_rETiC2ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JVgD7bJq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JVgD7bJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_K8IwvA26, m);
}

void Heavy_WSTD_DL3Y::sEnv_odQ1LWw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1tofkoId_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xZzw4Nnr_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_hpS1cbPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ovS4JaKs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Vk9hUZMS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_FgOR0Pzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_w1nr1MYZ, HV_BINOP_POW, 0, m, &cBinop_w1nr1MYZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w1nr1MYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4GQ8rJAC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sHtU21Ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_PgasbP3c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xZzw4Nnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hpS1cbPP, 0, m, &cIf_hpS1cbPP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1tofkoId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8NmLy311_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8NmLy311_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hpS1cbPP, 1, m, &cIf_hpS1cbPP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vk9hUZMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_sHtU21Ey_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ovS4JaKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_4GQ8rJAC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PgasbP3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w1nr1MYZ, HV_BINOP_POW, 1, m, &cBinop_w1nr1MYZ_sendMessage);
  cMsg_FgOR0Pzg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_X2IJW4h1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bu2NeutZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_bu2NeutZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tiDvZw8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oq200uls_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_oq200uls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Uu4B7oN4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bu2NeutZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JYfsRj8T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c8kS4mvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bu2NeutZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_bu2NeutZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Uu4B7oN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_c8kS4mvV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JYfsRj8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_J5FySvCl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J5FySvCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pMqqQkup_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_w7RVsEZ3, m);
}

void Heavy_WSTD_DL3Y::cBinop_pMqqQkup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_B2IV0J2l, m);
}

void Heavy_WSTD_DL3Y::cMsg_4GQ8rJAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ijOQwBcp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ijOQwBcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_12DoSdqy, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_7NVrQG9L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XLi4S974, 0, m, &cSlice_XLi4S974_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QWPbLb4X_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_XLi4S974_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_W7VRL24y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_W7VRL24y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_YevAvDzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_W7VRL24y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_W7VRL24y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pPZe8Eaw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_5IUTPQMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CcJpCV5b_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CcJpCV5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_m5EUVr1P_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_LBr5c4Zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LBr5c4Zk, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aGZQt0Wl, 0, m, &cDelay_aGZQt0Wl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LBr5c4Zk, 0, m, &cDelay_LBr5c4Zk_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_htJ9eyzG, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_aGZQt0Wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aGZQt0Wl, m);
  cMsg_L5QfK0Sp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_iCEOwAWf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_eARFzQtn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_m3llyk4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JmcmQKMh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_DNYritdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y4lUuXiT_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LBr5c4Zk, 2, m, &cDelay_LBr5c4Zk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m9PNMXgV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JmcmQKMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_DNYritdT, 0, m, &hTable_DNYritdT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_m5EUVr1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_m3llyk4U_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_L5QfK0Sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_DNYritdT, 0, m, &hTable_DNYritdT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_m9PNMXgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LBr5c4Zk, 0, m, &cDelay_LBr5c4Zk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Y4lUuXiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_aGZQt0Wl, 2, m, &cDelay_aGZQt0Wl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eARFzQtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_htJ9eyzG, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_ePfJuK21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cWvh5XSv, HV_BINOP_SUBTRACT, 0, m, &cBinop_cWvh5XSv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RJJfm8GP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JeXEYl2A_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JeXEYl2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2r04c4c3_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mkL8c0a5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PZGz7JAl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_kN2oplHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kN2oplHW, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kqsW3saM, 0, m, &cDelay_kqsW3saM_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LAseoey1, 0, m, &sTabread_LAseoey1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_kqsW3saM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kqsW3saM, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LAseoey1, 0, m, &sTabread_LAseoey1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kqsW3saM, 0, m, &cDelay_kqsW3saM_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_LAseoey1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DuFy9irL, HV_BINOP_SUBTRACT, 0, m, &cBinop_DuFy9irL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_exOdtGyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pb17LNEc, HV_BINOP_MAX, 0, m, &cBinop_Pb17LNEc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2r04c4c3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_exOdtGyP, HV_BINOP_MULTIPLY, 0, m, &cBinop_exOdtGyP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cWvh5XSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5ChRGlFl_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LAseoey1, 0, m, &sTabread_LAseoey1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LSeh9lk6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RNj89g5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DuFy9irL, HV_BINOP_SUBTRACT, 1, m, &cBinop_DuFy9irL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kqsW3saM, 2, m, &cDelay_kqsW3saM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PZGz7JAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RNj89g5a_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5ChRGlFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kN2oplHW, 0, m, &cDelay_kN2oplHW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kqsW3saM, 0, m, &cDelay_kqsW3saM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RmszX5eD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pb17LNEc, HV_BINOP_MAX, 1, m, &cBinop_Pb17LNEc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pb17LNEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cWvh5XSv, HV_BINOP_SUBTRACT, 1, m, &cBinop_cWvh5XSv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LSeh9lk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kN2oplHW, 0, m, &cDelay_kN2oplHW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4yFyKnWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kN2oplHW, 2, m, &cDelay_kN2oplHW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DuFy9irL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4yFyKnWw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Nk6anUTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mkL8c0a5, 0, m, &cVar_mkL8c0a5_sendMessage);
  cMsg_RJJfm8GP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ePfJuK21, 0, m, &cTabhead_ePfJuK21_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SqgvPbZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kHbSUuoO_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_kHbSUuoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4plC6JFb_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_a3KNOIqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a3KNOIqO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8bFQBSKS, 0, m, &cDelay_8bFQBSKS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_a3KNOIqO, 0, m, &cDelay_a3KNOIqO_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_sm9OnF6l, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_8bFQBSKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8bFQBSKS, m);
  cMsg_5NO2e7rj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_d25BWXrx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_pza7yUtE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_52IZHEcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iUXaflFZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_tesrntIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ep39DgGW_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_a3KNOIqO, 2, m, &cDelay_a3KNOIqO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M0GiLalG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iUXaflFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_tesrntIS, 0, m, &hTable_tesrntIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4plC6JFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_52IZHEcO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5NO2e7rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_tesrntIS, 0, m, &hTable_tesrntIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M0GiLalG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_a3KNOIqO, 0, m, &cDelay_a3KNOIqO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ep39DgGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_8bFQBSKS, 2, m, &cDelay_8bFQBSKS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pza7yUtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_sm9OnF6l, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_PM1dtp2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_utROhXnp, HV_BINOP_SUBTRACT, 0, m, &cBinop_utROhXnp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4nzIqiwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GURJAw9d_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_GURJAw9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VMwcVC7H_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_3zCfgQ08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4aNDCbjn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_1upZjZZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1upZjZZf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CSH8RbPa, 0, m, &cDelay_CSH8RbPa_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OS515Sc0, 0, m, &sTabread_OS515Sc0_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_CSH8RbPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CSH8RbPa, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OS515Sc0, 0, m, &sTabread_OS515Sc0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CSH8RbPa, 0, m, &cDelay_CSH8RbPa_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_OS515Sc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_olufSs3J, HV_BINOP_SUBTRACT, 0, m, &cBinop_olufSs3J_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_bhd8AzKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VaMACcgP, HV_BINOP_MAX, 0, m, &cBinop_VaMACcgP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VMwcVC7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bhd8AzKT, HV_BINOP_MULTIPLY, 0, m, &cBinop_bhd8AzKT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_utROhXnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Z5tK5uc_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OS515Sc0, 0, m, &sTabread_OS515Sc0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ao88kOta_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_c3ZHLmET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_olufSs3J, HV_BINOP_SUBTRACT, 1, m, &cBinop_olufSs3J_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CSH8RbPa, 2, m, &cDelay_CSH8RbPa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4aNDCbjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_c3ZHLmET_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1Z5tK5uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1upZjZZf, 0, m, &cDelay_1upZjZZf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CSH8RbPa, 0, m, &cDelay_CSH8RbPa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qLO0qIWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_VaMACcgP, HV_BINOP_MAX, 1, m, &cBinop_VaMACcgP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VaMACcgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_utROhXnp, HV_BINOP_SUBTRACT, 1, m, &cBinop_utROhXnp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ao88kOta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1upZjZZf, 0, m, &cDelay_1upZjZZf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CRicVJel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1upZjZZf, 2, m, &cDelay_1upZjZZf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_olufSs3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CRicVJel_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HJiaV3RL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3zCfgQ08, 0, m, &cVar_3zCfgQ08_sendMessage);
  cMsg_4nzIqiwF_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PM1dtp2u, 0, m, &cTabhead_PM1dtp2u_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F2wKhlhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EJzAyTEF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dx3GqbDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2ZOK8yuK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_sLVsZaIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2Ng7cm7u, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_PhOelZeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WxdpHsu7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_yX1a19Pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MAfdLDcd, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_L8v6K7pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XQSgRPcS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_w2s2VPXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TcFc9G7O, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JhsXUzVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hNB7W7Fp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_MUjeg1GT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3QQOfeA9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_P0Nk4UV4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_I2bPGm2t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3QQOfeA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MUjeg1GT, 1, m, &cVar_MUjeg1GT_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_De80G73G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wLbom7n5, 0, m, &cVar_wLbom7n5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_JMr8mfdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wLbom7n5, 0, m, &cVar_wLbom7n5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ZqsTwUCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JMr8mfdZ, 0, m, &cIf_JMr8mfdZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_5gr6y0Bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_De80G73G, 0, m, &cIf_De80G73G_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_StLU4fdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pQRpWXQU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ktmRqeWi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ogM4T1eV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pQRpWXQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_StLU4fdM, 1, m, &cVar_StLU4fdM_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_MMN5oOG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_UXUyAgt9, 0, m, &cVar_UXUyAgt9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_1oSbAOll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_UXUyAgt9, 0, m, &cVar_UXUyAgt9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_nNlEyoGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1oSbAOll, 0, m, &cIf_1oSbAOll_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_C0FFNTSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MMN5oOG9, 0, m, &cIf_MMN5oOG9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_hxH6Smuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_p8atiKPV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SxuSmpQJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WkxYqesa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p8atiKPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hxH6Smuo, 1, m, &cVar_hxH6Smuo_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_M1Ll1QDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_bX1eWhFI, 0, m, &cVar_bX1eWhFI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_iKgkNabo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_bX1eWhFI, 0, m, &cVar_bX1eWhFI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Y5ecarP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iKgkNabo, 0, m, &cIf_iKgkNabo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QJ8K3UB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M1Ll1QDf, 0, m, &cIf_M1Ll1QDf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_C57ObqvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dX1UatO, HV_BINOP_DIVIDE, 0, m, &cBinop_7dX1UatO_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_sTbyapYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TsZGaKgj, HV_BINOP_MULTIPLY, 1, m, &cBinop_TsZGaKgj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_5989wUTP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_klzJnQ2W, 0, m, &cSlice_klzJnQ2W_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VYPZ4IEo, 0, m, &cSlice_VYPZ4IEo_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PbZDhZV2_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pkhqNXAj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_klzJnQ2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_JNQj0sKy, 0, m, &cVar_JNQj0sKy_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_JNQj0sKy, 0, m, &cVar_JNQj0sKy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_VYPZ4IEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2Ewgk34b, HV_BINOP_NEQ, 1, m, &cBinop_2Ewgk34b_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_JNQj0sKy, 1, m, &cVar_JNQj0sKy_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2Ewgk34b, HV_BINOP_NEQ, 1, m, &cBinop_2Ewgk34b_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_JNQj0sKy, 1, m, &cVar_JNQj0sKy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_JNQj0sKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_wldJ3JDU_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_X4JQc8EA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fEJnCvY0_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a7yC6WJI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_a7yC6WJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JNQj0sKy, 0, m, &cVar_JNQj0sKy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fEJnCvY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Ewgk34b, HV_BINOP_NEQ, 1, m, &cBinop_2Ewgk34b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2Ewgk34b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X4JQc8EA, 1, m, &cIf_X4JQc8EA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PbZDhZV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Ewgk34b, HV_BINOP_NEQ, 0, m, &cBinop_2Ewgk34b_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pkhqNXAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X4JQc8EA, 0, m, &cIf_X4JQc8EA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_0QXN77aL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ch4YXNCo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_flU0vmOe_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_AiJZ8N2t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bVjCc6Tn_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L5odVv75_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SATeXeOW_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0yyxLLTd_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xM73qGfY_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BbeYz7v1_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SlFkqHhT_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lwk6GUYT_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fdogle5j_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XqWd2B3p_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1CS3WfvI_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oBKEQMK9_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cOY1qoqx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_bVjCc6Tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vngTLUxw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_L5odVv75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zhBBBiuL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_SATeXeOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QyDhEcmR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0yyxLLTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ihowf25f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_xM73qGfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6tqMXvgp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_BbeYz7v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QyDNeqtp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_SlFkqHhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pzHn1xul_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lwk6GUYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sL2oer8e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Fdogle5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xfCLfR9e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XqWd2B3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iBnjbpUD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_1CS3WfvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vo4luD9J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_oBKEQMK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fmn7NJF9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cOY1qoqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JMoDNm4w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7dX1UatO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TsZGaKgj, HV_BINOP_MULTIPLY, 0, m, &cBinop_TsZGaKgj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TsZGaKgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5989wUTP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_flU0vmOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C57ObqvK, 0, m, &cVar_C57ObqvK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sTbyapYy, 0, m, &cVar_sTbyapYy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ch4YXNCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dX1UatO, HV_BINOP_DIVIDE, 1, m, &cBinop_7dX1UatO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gjvzVPOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C57ObqvK, 0, m, &cVar_C57ObqvK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_529gC3vM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sTbyapYy, 0, m, &cVar_sTbyapYy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vngTLUxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zhBBBiuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QyDhEcmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ihowf25f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6tqMXvgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QyDNeqtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pzHn1xul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sL2oer8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xfCLfR9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iBnjbpUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Vo4luD9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Fmn7NJF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JMoDNm4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_529gC3vM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjvzVPOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_SzhAlv20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LuwMNLyQ, HV_BINOP_DIVIDE, 0, m, &cBinop_LuwMNLyQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_C5trURPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCf0gSGg, HV_BINOP_MULTIPLY, 1, m, &cBinop_JCf0gSGg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_6SbrX4oN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IpGubuON, 0, m, &cSlice_IpGubuON_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JACsOXyJ, 0, m, &cSlice_JACsOXyJ_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZqL9C604_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qFI9x8dn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_IpGubuON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_TzvFcjmk, 0, m, &cVar_TzvFcjmk_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TzvFcjmk, 0, m, &cVar_TzvFcjmk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_JACsOXyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Yawn892V, HV_BINOP_NEQ, 1, m, &cBinop_Yawn892V_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TzvFcjmk, 1, m, &cVar_TzvFcjmk_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Yawn892V, HV_BINOP_NEQ, 1, m, &cBinop_Yawn892V_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TzvFcjmk, 1, m, &cVar_TzvFcjmk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_TzvFcjmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_EDXtm6Y5_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_N1c28eNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yG8Fd3zU_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5fctvFjh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_5fctvFjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TzvFcjmk, 0, m, &cVar_TzvFcjmk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yG8Fd3zU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Yawn892V, HV_BINOP_NEQ, 1, m, &cBinop_Yawn892V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Yawn892V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N1c28eNG, 1, m, &cIf_N1c28eNG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZqL9C604_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Yawn892V, HV_BINOP_NEQ, 0, m, &cBinop_Yawn892V_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qFI9x8dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N1c28eNG, 0, m, &cIf_N1c28eNG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xSkFpl0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_srOfzKiW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IOLjlKWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_EQI0i1HQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G6NPz1sG_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hp4Z8HFX_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q6tIqOaH_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c6axiez8_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lpBdIDpK_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DfFyegXL_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_alfU1aLT_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I3V93XCz_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aFXOyyvf_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jxQbrkcj_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bTB3R5QI_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QJtu0MdY_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mo3SOvvS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_G6NPz1sG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bCgsDAU7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_hp4Z8HFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZbxFV8GV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_q6tIqOaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mogPpRVz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_c6axiez8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cgFJI3Jo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lpBdIDpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8UD8gAXJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_DfFyegXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_27ytDPFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_alfU1aLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WpJ8kZ4h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_I3V93XCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7iMHKXUN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aFXOyyvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7A41zoSW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_jxQbrkcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DFuouHRb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_bTB3R5QI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q2zWwg4V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QJtu0MdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_13DbCGtH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Mo3SOvvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_POUs6bNh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LuwMNLyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCf0gSGg, HV_BINOP_MULTIPLY, 0, m, &cBinop_JCf0gSGg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JCf0gSGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6SbrX4oN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_srOfzKiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LuwMNLyQ, HV_BINOP_DIVIDE, 1, m, &cBinop_LuwMNLyQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IOLjlKWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SzhAlv20, 0, m, &cVar_SzhAlv20_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C5trURPI, 0, m, &cVar_C5trURPI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MAKBcXUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SzhAlv20, 0, m, &cVar_SzhAlv20_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mOuKQBIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C5trURPI, 0, m, &cVar_C5trURPI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bCgsDAU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZbxFV8GV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mogPpRVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cgFJI3Jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8UD8gAXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_27ytDPFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WpJ8kZ4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7iMHKXUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7A41zoSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DFuouHRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Q2zWwg4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_13DbCGtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_POUs6bNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mOuKQBIK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAKBcXUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CJfpzcVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hVYspYr6, HV_BINOP_DIVIDE, 0, m, &cBinop_hVYspYr6_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_U7L61T1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CxFhFVS9, HV_BINOP_MULTIPLY, 1, m, &cBinop_CxFhFVS9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3939VNoX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mqDrh5aP, 0, m, &cSlice_mqDrh5aP_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tIeLh5y5, 0, m, &cSlice_tIeLh5y5_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KUAeB84d_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ef4tR6mb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_mqDrh5aP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_IzM2geM2, 0, m, &cVar_IzM2geM2_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_IzM2geM2, 0, m, &cVar_IzM2geM2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_tIeLh5y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_75QNcRB4, HV_BINOP_NEQ, 1, m, &cBinop_75QNcRB4_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_IzM2geM2, 1, m, &cVar_IzM2geM2_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_75QNcRB4, HV_BINOP_NEQ, 1, m, &cBinop_75QNcRB4_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_IzM2geM2, 1, m, &cVar_IzM2geM2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_IzM2geM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_mlLL4yG5_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_eyP33BWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qtaaRUFC_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bE8jIAyC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_qtaaRUFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_75QNcRB4, HV_BINOP_NEQ, 1, m, &cBinop_75QNcRB4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bE8jIAyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IzM2geM2, 0, m, &cVar_IzM2geM2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_75QNcRB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eyP33BWZ, 1, m, &cIf_eyP33BWZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ef4tR6mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eyP33BWZ, 0, m, &cIf_eyP33BWZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KUAeB84d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_75QNcRB4, HV_BINOP_NEQ, 0, m, &cBinop_75QNcRB4_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_v99OqnTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zflQVqo1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CyZX3VNV_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_sSbu8UFB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vCBtJAVH_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eqKoqXiu_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bs8IhbQf_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HwmMXzKE_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hXmQS0wq_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YAUqCP4Z_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5HBTrr6_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZgYACOMw_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uet03MbV_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_obGPLDQz_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sKR77uSH_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nlUSqmMG_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FXjAHItc_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_vCBtJAVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3XmUrK97_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eqKoqXiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uyUgfuJp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_bs8IhbQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IOYGTr17_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_HwmMXzKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GjvyTwGb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_hXmQS0wq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R84lEhb7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_YAUqCP4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rxa8QJVz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_c5HBTrr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0GItYXFc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZgYACOMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d8zmUEF6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uet03MbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YstRWtgd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_obGPLDQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LsfH5uqc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sKR77uSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cMrwXTZM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_nlUSqmMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8vOiz14d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FXjAHItc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hg1LHi2V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hVYspYr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CxFhFVS9, HV_BINOP_MULTIPLY, 0, m, &cBinop_CxFhFVS9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CxFhFVS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3939VNoX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_zflQVqo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hVYspYr6, HV_BINOP_DIVIDE, 1, m, &cBinop_hVYspYr6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CyZX3VNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CJfpzcVi, 0, m, &cVar_CJfpzcVi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_U7L61T1o, 0, m, &cVar_U7L61T1o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BjpnLarH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U7L61T1o, 0, m, &cVar_U7L61T1o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ICcoOu12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CJfpzcVi, 0, m, &cVar_CJfpzcVi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3XmUrK97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uyUgfuJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IOYGTr17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GjvyTwGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_R84lEhb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Rxa8QJVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0GItYXFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_d8zmUEF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YstRWtgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LsfH5uqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cMrwXTZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8vOiz14d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Hg1LHi2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjpnLarH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ICcoOu12_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7BeNsC7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4zRsSEqt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ju6jEl2H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fyk163OM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4zRsSEqt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ju6jEl2H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5PW7mOKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4zRsSEqt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ju6jEl2H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2a6btTZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4zRsSEqt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ju6jEl2H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ElXXM7HK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4zRsSEqt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ju6jEl2H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6VA4js5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_geZKhTIc, 0, m, &cVar_geZKhTIc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ag9Dhxiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_RPXKyyOi, 0, m, &cVar_RPXKyyOi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H8zC2EH3, 0, m, &cVar_H8zC2EH3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CM8U0isk, 0, m, &cVar_CM8U0isk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uOQBgvfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4qiIsMs4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ozstBjZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4qiIsMs4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_TV3ItSfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_upl7LidO, 0, m, &cVar_upl7LidO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ON8LIOno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Pz7IiZ4h, 0, m, &cVar_Pz7IiZ4h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dfRDwDgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AzHckjiT, 0, m, &cVar_AzHckjiT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_z3QarxbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4qiIsMs4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DORZAuTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4qiIsMs4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DhUDhaQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5o2v7end_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xi6PTMRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5o2v7end_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_voFrSXhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zLHlqDdI, 0, m, &cVar_zLHlqDdI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O8gm6c1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NDCK0Ko3, 0, m, &cVar_NDCK0Ko3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IJ3BCFZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zqSvPUYX, 0, m, &cVar_zqSvPUYX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yvC0Otj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5o2v7end_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Cn0QAG1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5o2v7end_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4E8ZX8Rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yAKcMYpL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kYwVKVir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yAKcMYpL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_X7chZ0Dq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_27Lh8F9I, 0, m, &cVar_27Lh8F9I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cCyAibDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XJzPYWdO, 0, m, &cVar_XJzPYWdO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PTqfvAPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_khUz6vQ2, 0, m, &cVar_khUz6vQ2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zNnu075l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yAKcMYpL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_pIN7BUNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yAKcMYpL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_wldJ3JDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5gr6y0Bf, 0, m, &cVar_5gr6y0Bf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I2bPGm2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fTeRDML9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7C3WT63V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P0Nk4UV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mgZwpRYT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uevIyaHp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mgZwpRYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JMr8mfdZ, 1, m, &cIf_JMr8mfdZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uevIyaHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZqsTwUCm, 0, m, &cVar_ZqsTwUCm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fTeRDML9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_De80G73G, 1, m, &cIf_De80G73G_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7C3WT63V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5gr6y0Bf, 0, m, &cVar_5gr6y0Bf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EDXtm6Y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C0FFNTSa, 0, m, &cVar_C0FFNTSa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ogM4T1eV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SolIQKWq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_63onQFWh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ktmRqeWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zRZadKH4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NhlRCiGt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NhlRCiGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nNlEyoGH, 0, m, &cVar_nNlEyoGH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zRZadKH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1oSbAOll, 1, m, &cIf_1oSbAOll_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_63onQFWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C0FFNTSa, 0, m, &cVar_C0FFNTSa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SolIQKWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MMN5oOG9, 1, m, &cIf_MMN5oOG9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mlLL4yG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QJ8K3UB9, 0, m, &cVar_QJ8K3UB9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WkxYqesa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hR9GdErn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_34G53eA5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SxuSmpQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z1vmgbXg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yAg5b6F9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_z1vmgbXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iKgkNabo, 1, m, &cIf_iKgkNabo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yAg5b6F9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y5ecarP3, 0, m, &cVar_Y5ecarP3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_34G53eA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QJ8K3UB9, 0, m, &cVar_QJ8K3UB9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hR9GdErn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M1Ll1QDf, 1, m, &cIf_M1Ll1QDf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_6bDX6uR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RPXKyyOi, 0, m, &cVar_RPXKyyOi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_COyUn54i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H8zC2EH3, 0, m, &cVar_H8zC2EH3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_fV5pVJXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CM8U0isk, 0, m, &cVar_CM8U0isk_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VPyT2SDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MLEcfNss, 0, m, &cVar_MLEcfNss_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ISjFR2Uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_if25DaOH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q4ZstquJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iAOusC2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CAxHm8xc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rfa7k03M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ySLYLFt2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_c07DpiIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RTjeN1mC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PNdnQEiW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1fkIiOwP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_EelTnX5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sQUj4XCs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PRwjKCGf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xBlid0Vs_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cCvGVLsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OBlRSw3O_sendMessage(_c, 0, m);
  cMsg_A1KmCoGZ_sendMessage(_c, 0, m);
  cMsg_6zN9LmJA_sendMessage(_c, 0, m);
  cMsg_3gLo44fb_sendMessage(_c, 0, m);
  cMsg_tMqMnk55_sendMessage(_c, 0, m);
  cMsg_EO0uAl4H_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_m3US40Fr, 0, m, &cVar_m3US40Fr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MLEcfNss, 0, m, &cVar_MLEcfNss_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WhM2yYxb, 0, m, &cVar_WhM2yYxb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TImns3GS, 0, m, &cVar_TImns3GS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8Om0u302, 0, m, &cVar_8Om0u302_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Gl0axYie, 0, m, &cVar_Gl0axYie_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vHambIEX, 0, m, &cVar_vHambIEX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6AEvqyYL, 0, m, &cVar_6AEvqyYL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PgvrsENs, 0, m, &cVar_PgvrsENs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lbvw8vXO, 0, m, &cVar_lbvw8vXO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pSRIDGyo, 0, m, &cVar_pSRIDGyo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5UYTfJx8, 0, m, &cVar_5UYTfJx8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_McYVz5jP, 0, m, &cVar_McYVz5jP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_V3Jq9Upj, 0, m, &cVar_V3Jq9Upj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FUjhbxH8, 0, m, &cVar_FUjhbxH8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TuJnkEyo, 0, m, &cVar_TuJnkEyo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LF48vs4x, 0, m, &cVar_LF48vs4x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cfLxEaI8, 0, m, &cVar_cfLxEaI8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IXiT00rK, 0, m, &cVar_IXiT00rK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z5xlp1EC, 0, m, &cVar_Z5xlp1EC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Vqcc5Gng, 0, m, &cVar_Vqcc5Gng_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZPBUUjFs, 0, m, &cVar_ZPBUUjFs_sendMessage);
  cMsg_wjmpl5ZN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xOAs8MeD, 0, m, &cVar_xOAs8MeD_sendMessage);
  cMsg_COYar3UU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Sk8hEjxd, 0, m, &cVar_Sk8hEjxd_sendMessage);
  cMsg_c6mD0EMC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_frTIvtwG, 0, m, &cVar_frTIvtwG_sendMessage);
  cMsg_bUEdngDm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eWUAFDJx, 0, m, &cVar_eWUAFDJx_sendMessage);
  cMsg_fbY06aRy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7JXDPl2B, 0, m, &cVar_7JXDPl2B_sendMessage);
  cMsg_tiDvZw8q_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_X2IJW4h1, 0, m, &cVar_X2IJW4h1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5r2GFnDP, 0, m, &cVar_5r2GFnDP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eeCNNVbK, 0, m, &cVar_eeCNNVbK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QSwPtEPQ, 0, m, &cVar_QSwPtEPQ_sendMessage);
  cMsg_1QBb8g4M_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TO0s0kQc, 0, m, &cVar_TO0s0kQc_sendMessage);
  cMsg_XlfSSseD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AZJWbHH1, 0, m, &cVar_AZJWbHH1_sendMessage);
  cMsg_RpvaZK4y_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dCwV0CS8, 0, m, &cVar_dCwV0CS8_sendMessage);
  cMsg_9FWhV4e9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_q5Nqp00O, 0, m, &cVar_q5Nqp00O_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hhZ7SzXP, 0, m, &cVar_hhZ7SzXP_sendMessage);
  cMsg_EULYJkLV_sendMessage(_c, 0, m);
  cMsg_I8ZfmG68_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3yifbHA8, 0, m, &cVar_3yifbHA8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_e6ar8BTK, 0, m, &cVar_e6ar8BTK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_d6r7N2ix, 0, m, &cVar_d6r7N2ix_sendMessage);
  cMsg_nT9Nw40x_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vlwpPazn, 0, m, &cVar_vlwpPazn_sendMessage);
  cMsg_x6fcIrfc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QVgfR36H, 0, m, &cVar_QVgfR36H_sendMessage);
  cMsg_owOsmxtP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XLNCODwD, 0, m, &cVar_XLNCODwD_sendMessage);
  cMsg_6u22RqjR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SXbN6DTP, 0, m, &cVar_SXbN6DTP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_axcj3w7O, 0, m, &cVar_axcj3w7O_sendMessage);
  cMsg_I3nMMid0_sendMessage(_c, 0, m);
  cMsg_LVE6SNor_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9BAYDLNm, 0, m, &cVar_9BAYDLNm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nuINDAUj, 0, m, &cVar_nuINDAUj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lSJH5rFP, 0, m, &cVar_lSJH5rFP_sendMessage);
  cMsg_g8DgLH0x_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HExhlo9d, 0, m, &cVar_HExhlo9d_sendMessage);
  cMsg_tuBv6agx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_APBEyypz, 0, m, &cVar_APBEyypz_sendMessage);
  cMsg_fUbo9TQw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_K5UJrBEC, 0, m, &cVar_K5UJrBEC_sendMessage);
  cMsg_Uh5n635q_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_j3PXL7fR, 0, m, &cVar_j3PXL7fR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YevAvDzo, 0, m, &cVar_YevAvDzo_sendMessage);
  cMsg_5IUTPQMc_sendMessage(_c, 0, m);
  cMsg_SqgvPbZJ_sendMessage(_c, 0, m);
  cMsg_Ag9Dhxiw_sendMessage(_c, 0, m);
  cMsg_6VA4js5I_sendMessage(_c, 0, m);
  cMsg_MfIDGqae_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QCRVe9xj, 0, m, &cVar_QCRVe9xj_sendMessage);
  cMsg_NBOr9unK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JiTHS9b2, 0, m, &cTabhead_JiTHS9b2_sendMessage);
  cMsg_KgfWnxYr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XHVzo0WA, 0, m, &cVar_XHVzo0WA_sendMessage);
  cMsg_J4r2hFEo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8ijs9hwY, 0, m, &cTabhead_8ijs9hwY_sendMessage);
  cMsg_u4rEgqrU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bvuPeikZ, 0, m, &cVar_bvuPeikZ_sendMessage);
  cMsg_yJAuXXyz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RcJsIeiH, 0, m, &cTabhead_RcJsIeiH_sendMessage);
  cMsg_ECEX9iX6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vSzkcySE, 0, m, &cVar_vSzkcySE_sendMessage);
  cMsg_MfmH7WeR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_9tMTbkXc, 0, m, &cTabhead_9tMTbkXc_sendMessage);
  cMsg_RmszX5eD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mkL8c0a5, 0, m, &cVar_mkL8c0a5_sendMessage);
  cMsg_RJJfm8GP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ePfJuK21, 0, m, &cTabhead_ePfJuK21_sendMessage);
  cMsg_qLO0qIWB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3zCfgQ08, 0, m, &cVar_3zCfgQ08_sendMessage);
  cMsg_4nzIqiwF_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_PM1dtp2u, 0, m, &cTabhead_PM1dtp2u_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_yt6OHiDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T1vFAwOs, HV_BINOP_MULTIPLY, 0, m, &cBinop_T1vFAwOs_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wY8vk8ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zknfjKDK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Q1doV66g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GHlj2MVy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_bJDIVhw0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Q8J3zVsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jHLNDNns_sendMessage);
  cMsg_jhcmZKcD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_GPSUcwE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8TbnSnfq, HV_BINOP_MULTIPLY, 0, m, &cBinop_8TbnSnfq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_erd4Hc5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_fi7Jj0mO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_UbkV6tgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oIpa1PKw, HV_BINOP_MULTIPLY, 1, m, &cBinop_oIpa1PKw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_g9lkWLkM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QzdyG0Us_sendMessage);
  cMsg_ZXX3WT5a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_rnoYavqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f8v9vxcH, HV_BINOP_MULTIPLY, 0, m, &cBinop_f8v9vxcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_t5jU9UOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_86Kv7FlK_sendMessage(_c, 0, m);
  cMsg_ZnSOzDbQ_sendMessage(_c, 0, m);
  cMsg_bcKD7DvW_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_PtTxI6rj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7hwyTjWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vyFLZT8E_sendMessage);
  cMsg_tqN7cMNZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_s0QuuQnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Om0u302, 0, m, &cVar_8Om0u302_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_DeR3gGaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6ADJqv4t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WiPERyCF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uZJO5j4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mZqy3U0b_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OHBhCY2T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jkLLnV0v_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vNEi5Cyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pi78kQgh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0EO008xH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yIS4Azg0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TAxeNlQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SNAxzfhB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YF5e8r0E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZnbBTUC1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Utwjky21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XGzsLLH4, HV_BINOP_MULTIPLY, 0, m, &cBinop_XGzsLLH4_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_IGB8Ytts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LYrcTQwQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_C4hDk5jH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nHgKAUnR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_WU5SqzAq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_0CRUgM0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aoMPiyfn_sendMessage);
  cMsg_88crsXL8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_A9Dj83tw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ROIPKFVU, HV_BINOP_MULTIPLY, 0, m, &cBinop_ROIPKFVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_T7DZ17Jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_pWHkGk50_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_IfRxJR1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MIMxq6L2, HV_BINOP_MULTIPLY, 1, m, &cBinop_MIMxq6L2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IccKm7J4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OdKG2zaj_sendMessage);
  cMsg_8vdr6glg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_MnCf1hvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1lKt6NJw, HV_BINOP_MULTIPLY, 0, m, &cBinop_1lKt6NJw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cdq2v69z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eXt2CXfn_sendMessage(_c, 0, m);
  cMsg_BYu3WEp4_sendMessage(_c, 0, m);
  cMsg_BkbWL37S_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_QUzwqk5r_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_UsLJvktH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0PATZTJS_sendMessage);
  cMsg_htikBbXm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_DMZFhPHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_geZKhTIc, 0, m, &cVar_geZKhTIc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YKbuY0cC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TV3ItSfi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZwlplDF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ON8LIOno_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MHkO9co3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_dfRDwDgj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pOyRWLJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_voFrSXhL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_S2f7eEiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_O8gm6c1X_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kHPeG26V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_X7chZ0Dq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tBLgzTLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_cCyAibDh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RDHN9K3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_PTqfvAPv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Il7XpjeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_IJ3BCFZA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_fWbuFqmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DGqrMahT, HV_BINOP_MULTIPLY, 1, m, &cBinop_DGqrMahT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lDSYe8PG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ezaN5XMn, HV_BINOP_MULTIPLY, 1, m, &cBinop_ezaN5XMn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_slouxSJc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_32lznS3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xsGiZMWw, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_D5LzNP7Q, m);
}

void Heavy_WSTD_DL3Y::cReceive_sje1c79Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_iPpdlong_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_77mb2aQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XdBPtmLG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Xs7sgA8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nZ2V9UTq, HV_BINOP_MULTIPLY, 1, m, &cBinop_nZ2V9UTq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ySHu0WTW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_84ywi2q3, HV_BINOP_MULTIPLY, 1, m, &cBinop_84ywi2q3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QYOvR1rc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nSR5PB83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kIyTfmGz, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MDiFpYpi, m);
}

void Heavy_WSTD_DL3Y::cReceive_mgfnvyBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rPCFlLwm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Ky3vptrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SrAIX3hR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_PLz3uVAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_exOdtGyP, HV_BINOP_MULTIPLY, 1, m, &cBinop_exOdtGyP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Nk6anUTu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bhd8AzKT, HV_BINOP_MULTIPLY, 1, m, &cBinop_bhd8AzKT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HJiaV3RL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pPZe8Eaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VcbUlWtG, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_IF57ip2X, m);
}

void Heavy_WSTD_DL3Y::cReceive_JkOba6ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KJZkGDdG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_LW4SbsDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZwOfChlR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_dCWK3LHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZqsTwUCm, 0, m, &cVar_ZqsTwUCm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_CDV4bBYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MUjeg1GT, 0, m, &cVar_MUjeg1GT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iMovIJWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_StLU4fdM, 0, m, &cVar_StLU4fdM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_u8OEwq1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nNlEyoGH, 0, m, &cVar_nNlEyoGH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_w8H1hHXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y5ecarP3, 0, m, &cVar_Y5ecarP3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Q2YSabZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hxH6Smuo, 0, m, &cVar_hxH6Smuo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_UT05hS5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0QXN77aL, 0, m, &cVar_0QXN77aL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xSkFpl0d, 0, m, &cVar_xSkFpl0d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v99OqnTZ, 0, m, &cVar_v99OqnTZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zf3Odeqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EQI0i1HQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_CRrQ3LsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AiJZ8N2t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_KQk1WNB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sSbu8UFB_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_nsV4uerq, VOf(Bf0));
    __hv_line_f(&sLine_dPLnR4QL, VOf(Bf1));
    __hv_line_f(&sLine_YKQB8PKl, VOf(Bf2));
    __hv_line_f(&sLine_jXHFwSib, VOf(Bf3));
    __hv_line_f(&sLine_gVayQMOm, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_0P8UIzwz, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_6SSw5Axv, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_VOKkhjXp, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_lgVH9r9P, VOf(Bf1));
    __hv_line_f(&sLine_TgyCRvRG, VOf(Bf0));
    __hv_line_f(&sLine_S5iDjuYX, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_NOuDRmMH, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_5N2N1hgI, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_AlIOUUeS, VOf(Bf5));
    __hv_line_f(&sLine_nHfrXWhg, VOf(Bf1));
    __hv_line_f(&sLine_ep8OsNgw, VOf(Bf2));
    __hv_line_f(&sLine_OA2PzEqD, VOf(Bf4));
    __hv_line_f(&sLine_nnoMMfhe, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_VQ7aJQpz, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_59UxGIX9, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_opGiacve, VOf(Bf6));
    __hv_line_f(&sLine_5hAg9a0S, VOf(Bf2));
    __hv_line_f(&sLine_ooVqBI9U, VOf(Bf1));
    __hv_line_f(&sLine_2AM9LelM, VOf(Bf5));
    __hv_line_f(&sLine_rM9KBoYO, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_hekgEUPy, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_M6xarT90, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_yWj0Hgbk, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_lE8eUZX3, VOf(Bf2));
    __hv_line_f(&sLine_tswci10b, VOf(Bf6));
    __hv_line_f(&sLine_hfciy1kH, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_MUFCtdsC, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_WKow0uYQ, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_F2HZ0jbP, VOf(Bf8));
    __hv_line_f(&sLine_tGyecyQ6, VOf(Bf2));
    __hv_line_f(&sLine_Bryel1eD, VOf(Bf1));
    __hv_line_f(&sLine_rqxQoYkY, VOf(Bf7));
    __hv_line_f(&sLine_8kkCvHsm, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_M8qI879e, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_n9u48uKW, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_LOR5GWii, VOf(Bf9));
    __hv_tabread_f(&sTabread_9cFKXxWJ, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_1JYytvCh, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_CeKf1w9K, VOf(Bf9));
    __hv_tabread_f(&sTabread_vWg9xjYC, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_zD2bQONr, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_XSFm1GSZ, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_sx31WiGk, VOf(Bf3));
    __hv_rpole_f(&sRPole_WbtABGCR, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_TzWsLRnE, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_jtkLSGqn, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_yVYXdgmK, VIf(Bf3));
    __hv_varread_f(&sVarf_T3Z5LTXx, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_N9BPWZfv, VOf(Bf5));
    __hv_rpole_f(&sRPole_D1XwAmGm, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_ERiELeAC, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_skHSI109, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_SmPzUxpL, VIf(Bf5));
    __hv_varread_f(&sVarf_xsGiZMWw, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Hd762wSD, VOf(Bf1));
    __hv_varread_f(&sVarf_D5LzNP7Q, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_ZDtrzvZ7, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_dWlyBku3, VOf(Bf1));
    __hv_varread_f(&sVarf_PyRPJVuT, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_14ZPZnd8, VOf(Bf1));
    __hv_rpole_f(&sRPole_pTIEM7rb, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_tfLSvRCy, VIf(Bf8), &sEnv_tfLSvRCy_sendMessage);
    __hv_varread_f(&sVarf_RYWaEv3h, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_pek8aLU3, VOf(Bf1));
    __hv_rpole_f(&sRPole_dIcZ79W1, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_XSFm1GSZ, VIf(Bf1));
    __hv_line_f(&sLine_yzEumBOQ, VOf(Bf1));
    __hv_line_f(&sLine_skU88LJ9, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_3zAt7r5c, VOf(Bf1));
    __hv_varread_f(&sVarf_l2zoK9xY, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_L3YdiH04, VOf(Bf1));
    __hv_rpole_f(&sRPole_VC5iGLgC, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_55KP6IoN, VIf(Bf8), &sEnv_55KP6IoN_sendMessage);
    __hv_varread_f(&sVarf_OZQWpaI0, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_qYVbZbpp, VOf(Bf1));
    __hv_rpole_f(&sRPole_DM6Tjmvu, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_T3Z5LTXx, VIf(Bf1));
    __hv_varwrite_f(&sVarf_UirnNsyw, VIf(Bf2));
    __hv_varread_f(&sVarf_bnvHxPYx, VOf(Bf2));
    __hv_varread_f(&sVarf_3G6IpaMZ, VOf(Bf1));
    __hv_line_f(&sLine_YhgjhRjv, VOf(Bf8));
    __hv_tabread_f(&sTabread_hxDx1eyJ, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_XWI1IyDr, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Jza4JCsW, VOf(Bf8));
    __hv_tabread_f(&sTabread_Y3KqbIuB, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_0angkyHi, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_xtiolNpd, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_dad4jLYG, VOf(Bf2));
    __hv_rpole_f(&sRPole_EFPxPgKV, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_W4yP4xoV, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_EHMnHpFk, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_ktViRj5c, VIf(Bf2));
    __hv_varread_f(&sVarf_rYGPYTpp, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_nBK5Q9GP, VOf(Bf1));
    __hv_rpole_f(&sRPole_kHH2wQmr, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_KyCNnAur, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_EsNytzSR, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_Xy6G5mBv, VIf(Bf1));
    __hv_varread_f(&sVarf_kIyTfmGz, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_pjIOgGQ4, VOf(Bf3));
    __hv_varread_f(&sVarf_MDiFpYpi, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_c2Rc1CcA, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_4Gbu39bu, VOf(Bf3));
    __hv_varread_f(&sVarf_uEPVgiph, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_fkQJci3v, VOf(Bf3));
    __hv_rpole_f(&sRPole_UgDflWbC, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_pC0haLX8, VIf(Bf9), &sEnv_pC0haLX8_sendMessage);
    __hv_varread_f(&sVarf_8rm93nrG, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_6bm6zYOo, VOf(Bf3));
    __hv_rpole_f(&sRPole_mUW6aisG, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_xtiolNpd, VIf(Bf3));
    __hv_line_f(&sLine_mBX0svRQ, VOf(Bf3));
    __hv_line_f(&sLine_OHWFhFQT, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_1M7sNqMW, VOf(Bf3));
    __hv_varread_f(&sVarf_ObrkNkPi, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_L7VNmyLZ, VOf(Bf3));
    __hv_rpole_f(&sRPole_4dptRfFn, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_taa6etC3, VIf(Bf9), &sEnv_taa6etC3_sendMessage);
    __hv_varread_f(&sVarf_noaOPQBm, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_tGhZiupz, VOf(Bf3));
    __hv_rpole_f(&sRPole_8MkHgJw4, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_rYGPYTpp, VIf(Bf3));
    __hv_varwrite_f(&sVarf_lxBPTc60, VIf(Bf5));
    __hv_varread_f(&sVarf_lrnXb0sb, VOf(Bf5));
    __hv_varread_f(&sVarf_2rkQ7gMC, VOf(Bf3));
    __hv_line_f(&sLine_2ZOK8yuK, VOf(Bf9));
    __hv_tabread_f(&sTabread_LAseoey1, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_EJzAyTEF, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_2Ng7cm7u, VOf(Bf9));
    __hv_tabread_f(&sTabread_OS515Sc0, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_WxdpHsu7, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_PJLHjhVd, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_iSDBH07R, VOf(Bf5));
    __hv_rpole_f(&sRPole_Fufab77Z, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_1V6cniFf, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_pCtS5Ub7, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_htJ9eyzG, VIf(Bf5));
    __hv_varread_f(&sVarf_NgjzAzQR, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_4U9gcFBv, VOf(Bf3));
    __hv_rpole_f(&sRPole_HBvdx3nj, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_pMJx9bfd, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_aLXQHzo8, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_sm9OnF6l, VIf(Bf3));
    __hv_varread_f(&sVarf_VcbUlWtG, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_XQSgRPcS, VOf(Bf2));
    __hv_varread_f(&sVarf_IF57ip2X, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_MAfdLDcd, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_K8IwvA26, VOf(Bf2));
    __hv_varread_f(&sVarf_f2wrFm8M, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_CUqx9Jid, VOf(Bf2));
    __hv_rpole_f(&sRPole_LQyVr4E0, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_lX4ULbZb, VIf(Bf8), &sEnv_lX4ULbZb_sendMessage);
    __hv_varread_f(&sVarf_TXimwrM2, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_8ejYyDhg, VOf(Bf2));
    __hv_rpole_f(&sRPole_HeKEWwJe, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_PJLHjhVd, VIf(Bf2));
    __hv_line_f(&sLine_hNB7W7Fp, VOf(Bf2));
    __hv_line_f(&sLine_TcFc9G7O, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_12DoSdqy, VOf(Bf2));
    __hv_varread_f(&sVarf_w7RVsEZ3, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_B2IV0J2l, VOf(Bf2));
    __hv_rpole_f(&sRPole_eYu6ew5q, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_odQ1LWw0, VIf(Bf8), &sEnv_odQ1LWw0_sendMessage);
    __hv_varread_f(&sVarf_J8GQdxlw, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_o28JgQuI, VOf(Bf2));
    __hv_rpole_f(&sRPole_Y5Idb3QT, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_NgjzAzQR, VIf(Bf2));
    __hv_varwrite_f(&sVarf_Wp3jadmS, VIf(Bf1));
    __hv_varwrite_f(&sVarf_HP7JYirX, VIf(Bf10));
    __hv_varwrite_f(&sVarf_E3Na4puX, VIf(Bf11));
    __hv_varwrite_f(&sVarf_55ycLMFI, VIf(Bf12));
    __hv_varwrite_f(&sVarf_bnvHxPYx, VIf(Bf0));
    __hv_varwrite_f(&sVarf_3G6IpaMZ, VIf(Bf6));
    __hv_varwrite_f(&sVarf_lrnXb0sb, VIf(Bf4));
    __hv_varwrite_f(&sVarf_2rkQ7gMC, VIf(Bf7));
    __hv_varread_f(&sVarf_HP7JYirX, VOf(Bf7));
    __hv_varread_f(&sVarf_E3Na4puX, VOf(Bf4));
    __hv_varread_f(&sVarf_55ycLMFI, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_UirnNsyw, VOf(Bf6));
    __hv_varread_f(&sVarf_lxBPTc60, VOf(Bf7));
    __hv_varread_f(&sVarf_Wp3jadmS, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
